@@ -15,7 +15,6 @@
 #    under the License.
 
 import re
-import six
 
 from manila.api.openstack import versioned_method
 from manila import exception
@@ -171,14 +170,29 @@ REST_API_VERSION_HISTORY = """
              actions on the share network's endpoint:
              'update_security_service', 'update_security_service_check' and
              'add_security_service_check'.
-    * 2.65 - Added ability to set scheduler hints via the share create API.
+    * 2.64 - Added 'force' field to extend share api, which can extend share
+             directly without validation through share scheduler.
+    * 2.65 - Added ability to set affinity scheduler hints via the share
+             create API.
+    * 2.66 - Added filter search by group spec for share group type list.
+    * 2.67 - Added ability to set 'only_host' scheduler hint for the share
+             create and share replica create API.
+    * 2.68 - Added admin only capabilities to share metadata API
+    * 2.69 - Added new share action to soft delete share to recycle bin or
+             restore share from recycle bin. Also, a new parameter called
+             `is_soft_deleted` was added so users can filter out
+             shares in the recycle bin while listing shares.
+    * 2.70 - Added support for multiple share network subnets in the same
+             availability zone. Also, users can add subnets for an in-use share
+             network.
+
 """
 
 # The minimum and maximum versions of the API supported
 # The default api version request is defined to be the
 # minimum version of the API supported.
 _MIN_API_VERSION = "2.0"
-_MAX_API_VERSION = "2.65"
+_MAX_API_VERSION = "2.70"
 DEFAULT_API_VERSION = _MIN_API_VERSION
 
 
@@ -281,9 +295,9 @@ class APIVersionRequest(utils.ComparableMixin):
         if not self.experimental and experimental:
             return False
 
-        if isinstance(min_version, six.string_types):
+        if isinstance(min_version, str):
             min_version = APIVersionRequest(version_string=min_version)
-        if isinstance(max_version, six.string_types):
+        if isinstance(max_version, str):
             max_version = APIVersionRequest(version_string=max_version)
 
         if not (min_version or max_version):
