@@ -13,8 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-from six.moves import http_client
+from http import client as http_client
+
 import webob
 
 from manila.api import common
@@ -50,10 +50,10 @@ class ShareTypeExtraSpecsController(wsgi.Controller):
             try:
                 share_types.get_valid_required_extra_specs(extra_specs)
             except exception.InvalidExtraSpec as e:
-                raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
+                raise webob.exc.HTTPBadRequest(explanation=e.message)
 
         def is_valid_string(v):
-            return isinstance(v, six.string_types) and len(v) in range(1, 256)
+            return isinstance(v, str) and len(v) in range(1, 256)
 
         def is_valid_extra_spec(k, v):
             valid_extra_spec_key = is_valid_string(k)
