@@ -16,12 +16,11 @@
 """The shares api."""
 
 import ast
+from http import client as http_client
 
 from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client
 import webob
 from webob import exc
 
@@ -91,9 +90,9 @@ class ShareMixin(object):
         except exception.NotFound:
             raise exc.HTTPNotFound()
         except exception.InvalidShare as e:
-            raise exc.HTTPForbidden(explanation=six.text_type(e))
+            raise exc.HTTPForbidden(explanation=e.message)
         except exception.Conflict as e:
-            raise exc.HTTPConflict(explanation=six.text_type(e))
+            raise exc.HTTPConflict(explanation=e.message)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -136,6 +135,11 @@ class ShareMixin(object):
                 'with_count', search_opts)
             search_opts.pop('with_count')
 
+        if 'is_soft_deleted' in search_opts:
+            is_soft_deleted = utils.get_bool_from_api_params(
+                'is_soft_deleted', search_opts)
+            search_opts['is_soft_deleted'] = is_soft_deleted
+
         # Deserialize dicts
         if 'metadata' in search_opts:
             search_opts['metadata'] = ast.literal_eval(search_opts['metadata'])
@@ -193,7 +197,7 @@ class ShareMixin(object):
             'is_public', 'metadata', 'extra_specs', 'sort_key', 'sort_dir',
             'share_group_id', 'share_group_snapshot_id', 'export_location_id',
             'export_location_path', 'display_name~', 'display_description~',
-            'display_description', 'limit', 'offset')
+            'display_description', 'limit', 'offset', 'is_soft_deleted')
 
     @wsgi.Controller.authorize
     def update(self, req, id, body):
@@ -219,6 +223,11 @@ class ShareMixin(object):
         except exception.NotFound:
             raise exc.HTTPNotFound()
 
+        if share.get('is_soft_deleted'):
+            msg = _("Share '%s cannot be updated, "
+                    "since it has been soft deleted.") % share['id']
+            raise exc.HTTPForbidden(explanation=msg)
+
         update_dict = common.validate_public_share_policy(
             context, update_dict, api='update')
 
@@ -273,14 +282,14 @@ class ShareMixin(object):
                 availability_zone_id = availability_zone_db.id
                 availability_zone = availability_zone_db.name
             except exception.AvailabilityZoneNotFound as e:
-                raise exc.HTTPNotFound(explanation=six.text_type(e))
+                raise exc.HTTPNotFound(explanation=e.message)
 
         share_group_id = share.get('share_group_id')
         if share_group_id:
             try:
                 share_group = db.share_group_get(context, share_group_id)
             except exception.ShareGroupNotFound as e:
-                raise exc.HTTPNotFound(explanation=six.text_type(e))
+                raise exc.HTTPNotFound(explanation=e.message)
             sg_az_id = share_group['availability_zone_id']
             if availability_zone and availability_zone_id != sg_az_id:
                 msg = _("Share cannot have AZ ('%(s_az)s') different than "
@@ -346,12 +355,17 @@ class ShareMixin(object):
             common.check_share_network_is_active(share_network)
 
             if availability_zone_id:
-                if not db.share_network_subnet_get_by_availability_zone_id(
+                subnets = (
+                    db.share_network_subnets_get_all_by_availability_zone_id(
                         context, share_network_id,
-                        availability_zone_id=availability_zone_id):
+                        availability_zone_id=availability_zone_id))
+                if not subnets:
                     msg = _("A share network subnet was not found for the "
                             "requested availability zone.")
                     raise exc.HTTPBadRequest(explanation=msg)
+                kwargs['az_request_multiple_subnet_support_map'] = {
+                    availability_zone_id: len(subnets) > 1,
+                }
 
         display_name = share.get('display_name')
         display_description = share.get('display_description')
@@ -444,6 +458,10 @@ class ShareMixin(object):
             access_data.pop('metadata', None)
         share = self.share_api.get(context, id)
 
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot allow access for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
         share_network_id = share.get('share_network_id')
         if share_network_id:
             share_network = db.share_network_get(context, share_network_id)
@@ -491,6 +509,12 @@ class ShareMixin(object):
             'deny_access', body.get('os-deny_access'))['access_id']
 
         share = self.share_api.get(context, id)
+
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot deny access for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+
         share_network_id = share.get('share_network_id', None)
 
         if share_network_id:
@@ -503,7 +527,7 @@ class ShareMixin(object):
                 raise exception.NotFound()
             share = self.share_api.get(context, id)
         except exception.NotFound as error:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(error))
+            raise webob.exc.HTTPNotFound(explanation=error.message)
         self.share_api.deny_access(context, share, access)
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -522,12 +546,17 @@ class ShareMixin(object):
         share, size, force = self._get_valid_extend_parameters(
             context, id, body, 'os-extend')
 
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot extend share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+
         try:
             self.share_api.extend(context, share, size, force=force)
         except (exception.InvalidInput, exception.InvalidShare) as e:
-            raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=e.message)
         except exception.ShareSizeExceedsAvailableQuota as e:
-            raise webob.exc.HTTPForbidden(explanation=six.text_type(e))
+            raise webob.exc.HTTPForbidden(explanation=e.message)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -537,10 +566,15 @@ class ShareMixin(object):
         share, size = self._get_valid_shrink_parameters(
             context, id, body, 'os-shrink')
 
+        if share.get('is_soft_deleted'):
+            msg = _("Cannot shrink share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
+
         try:
             self.share_api.shrink(context, share, size)
         except (exception.InvalidInput, exception.InvalidShare) as e:
-            raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=e.message)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -548,7 +582,7 @@ class ShareMixin(object):
         try:
             share = self.share_api.get(context, id)
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.message)
 
         try:
             size = int(body.get(action, body.get('extend'))['new_size'])
@@ -574,7 +608,7 @@ class ShareMixin(object):
         try:
             share = self.share_api.get(context, id)
         except exception.NotFound as e:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(e))
+            raise webob.exc.HTTPNotFound(explanation=e.message)
 
         try:
             size = int(body.get(action, body.get('shrink'))['new_size'])
