@@ -20,6 +20,7 @@ from manila.api.views import export_locations as export_locations_views
 from manila.db import api as db_api
 from manila import exception
 from manila.i18n import _
+from manila import policy
 
 
 class ShareExportLocationController(wsgi.Controller):
@@ -32,7 +33,9 @@ class ShareExportLocationController(wsgi.Controller):
 
     def _verify_share(self, context, share_id):
         try:
-            db_api.share_get(context, share_id)
+            share = db_api.share_get(context, share_id)
+            if not share['is_public']:
+                policy.check_policy(context, 'share', 'get', share)
         except exception.NotFound:
             msg = _("Share '%s' not found.") % share_id
             raise exc.HTTPNotFound(explanation=msg)
@@ -74,7 +77,7 @@ class ShareExportLocationController(wsgi.Controller):
         return self._index(req, share_id)
 
     @wsgi.Controller.api_version('2.47')  # noqa: F811
-    def index(self, req, share_id):  # pylint: disable=function-redefined
+    def index(self, req, share_id):  # pylint: disable=function-redefined  # noqa F811
         """Return a list of export locations for share."""
         return self._index(req, share_id,
                            ignore_secondary_replicas=True)
@@ -85,7 +88,7 @@ class ShareExportLocationController(wsgi.Controller):
         return self._show(req, share_id, export_location_uuid)
 
     @wsgi.Controller.api_version('2.47')  # noqa: F811
-    def show(self, req, share_id,  # pylint: disable=function-redefined
+    def show(self, req, share_id,  # pylint: disable=function-redefined  # noqa F811
              export_location_uuid):
         """Return data about the requested export location."""
         return self._show(req, share_id, export_location_uuid,
