@@ -13,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
+
 from oslo_log import log
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client
 import webob
 from webob import exc
 
@@ -65,7 +65,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         return self._show(req, id)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def show(self, req, id):  # pylint: disable=function-redefined
+    def show(self, req, id):  # pylint: disable=function-redefined  # noqa F811
         return self._show(req, id)
 
     @wsgi.Controller.authorize('delete')
@@ -78,7 +78,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         try:
             self.share_group_api.delete(context, share_group)
         except exception.InvalidShareGroup as e:
-            raise exc.HTTPConflict(explanation=six.text_type(e))
+            raise exc.HTTPConflict(explanation=e.message)
         return webob.Response(status_int=http_client.ACCEPTED)
 
     @wsgi.Controller.api_version('2.31', '2.54', experimental=True)
@@ -86,7 +86,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         return self._delete_share_group(req, id)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def delete(self, req, id):  # pylint: disable=function-redefined
+    def delete(self, req, id):  # pylint: disable=function-redefined  # noqa F811
         return self._delete_share_group(req, id)
 
     @wsgi.Controller.api_version('2.31', '2.54', experimental=True)
@@ -94,7 +94,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         return self._get_share_groups(req, is_detail=False)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def index(self, req):  # pylint: disable=function-redefined
+    def index(self, req):  # pylint: disable=function-redefined  # noqa F811
         return self._get_share_groups(req, is_detail=False)
 
     @wsgi.Controller.api_version('2.31', '2.54', experimental=True)
@@ -102,7 +102,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         return self._get_share_groups(req, is_detail=True)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def detail(self, req):  # pylint: disable=function-redefined
+    def detail(self, req):  # pylint: disable=function-redefined  # noqa F811
         return self._get_share_groups(req, is_detail=True)
 
     @wsgi.Controller.authorize('get_all')
@@ -164,7 +164,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         return self._update_share_group(req, id, body)
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
-    def update(self, req, id, body):  # pylint: disable=function-redefined
+    def update(self, req, id, body):  # pylint: disable=function-redefined  # noqa F811
         return self._update_share_group(req, id, body)
 
     @wsgi.Controller.authorize('create')
@@ -241,7 +241,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
                 kwargs['availability_zone_id'] = az.id
                 kwargs['availability_zone'] = az.name
             except exception.AvailabilityZoneNotFound as e:
-                raise exc.HTTPNotFound(explanation=six.text_type(e))
+                raise exc.HTTPNotFound(explanation=e.message)
 
         if 'source_share_group_snapshot_id' in share_group:
             source_share_group_snapshot_id = share_group.get(
@@ -249,21 +249,21 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
             if not uuidutils.is_uuid_like(source_share_group_snapshot_id):
                 msg = _("The 'source_share_group_snapshot_id' attribute "
                         "must be a uuid.")
-                raise exc.HTTPBadRequest(explanation=six.text_type(msg))
+                raise exc.HTTPBadRequest(explanation=msg)
             kwargs['source_share_group_snapshot_id'] = (
                 source_share_group_snapshot_id)
         elif 'share_network_id' in share_group:
             share_network_id = share_group.get('share_network_id')
             if not uuidutils.is_uuid_like(share_network_id):
                 msg = _("The 'share_network_id' attribute must be a uuid.")
-                raise exc.HTTPBadRequest(explanation=six.text_type(msg))
+                raise exc.HTTPBadRequest(explanation=msg)
             kwargs['share_network_id'] = share_network_id
 
         if 'share_group_type_id' in share_group:
             share_group_type_id = share_group.get('share_group_type_id')
             if not uuidutils.is_uuid_like(share_group_type_id):
                 msg = _("The 'share_group_type_id' attribute must be a uuid.")
-                raise exc.HTTPBadRequest(explanation=six.text_type(msg))
+                raise exc.HTTPBadRequest(explanation=msg)
             kwargs['share_group_type_id'] = share_group_type_id
         else:  # get default
             def_share_group_type = share_group_types.get_default()
@@ -277,10 +277,10 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
         try:
             new_share_group = self.share_group_api.create(context, **kwargs)
         except exception.InvalidShareGroupSnapshot as e:
-            raise exc.HTTPConflict(explanation=six.text_type(e))
+            raise exc.HTTPConflict(explanation=e.message)
         except (exception.ShareGroupSnapshotNotFound,
                 exception.InvalidInput) as e:
-            raise exc.HTTPBadRequest(explanation=six.text_type(e))
+            raise exc.HTTPBadRequest(explanation=e.message)
 
         return self._view_builder.detail(
             req, {k: v for k, v in new_share_group.items()})
@@ -292,7 +292,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
 
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.response(202)
-    def create(self, req, body):  # pylint: disable=function-redefined
+    def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         return self._create(req, body)
 
     def _update(self, *args, **kwargs):
@@ -320,7 +320,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
     # pylint: disable=function-redefined
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.action('reset_status')
-    def share_group_reset_status(self, req, id, body):
+    def share_group_reset_status(self, req, id, body):  # noqa F811
         return self._reset_status(req, id, body)
 
     # pylint: enable=function-redefined
@@ -332,7 +332,7 @@ class ShareGroupController(wsgi.Controller, wsgi.AdminActionsMixin):
     # pylint: disable=function-redefined
     @wsgi.Controller.api_version(SG_GRADUATION_VERSION)  # noqa
     @wsgi.action('force_delete')
-    def share_group_force_delete(self, req, id, body):
+    def share_group_force_delete(self, req, id, body):  # noqa F811
         return self._force_delete(req, id, body)
 
 
