@@ -16,15 +16,15 @@
 """The share type API controller module.."""
 
 import ast
+from http import client as http_client
 
 from oslo_log import log
 from oslo_utils import strutils
 from oslo_utils import uuidutils
-import six
-from six.moves import http_client
 import webob
 from webob import exc
 
+from manila.api import common
 from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
 from manila.api.views import types as views_types
@@ -84,7 +84,6 @@ class ShareTypesController(wsgi.Controller):
             msg = _("Share type not found.")
             raise exc.HTTPNotFound(explanation=msg)
 
-        share_type['id'] = six.text_type(share_type['id'])
         req.cache_db_share_type(share_type)
         return self._view_builder.show(req, share_type)
 
@@ -116,7 +115,6 @@ class ShareTypesController(wsgi.Controller):
             msg = _("Default share type not found")
             raise exc.HTTPNotFound(explanation=msg)
 
-        share_type['id'] = six.text_type(share_type['id'])
         return self._view_builder.show(req, share_type)
 
     def _get_share_types(self, req):
@@ -125,7 +123,7 @@ class ShareTypesController(wsgi.Controller):
         context = req.environ['manila.context']
         if context.is_admin:
             # Only admin has query access to all share types
-            filters['is_public'] = self._parse_is_public(
+            filters['is_public'] = common.parse_is_public(
                 req.params.get('is_public'))
         else:
             filters['is_public'] = True
@@ -148,26 +146,6 @@ class ShareTypesController(wsgi.Controller):
             context, search_opts=filters).values()
         return list(limited_types)
 
-    @staticmethod
-    def _parse_is_public(is_public):
-        """Parse is_public into something usable.
-
-        * True: API should list public share types only
-        * False: API should list private share types only
-        * None: API should list both public and private share types
-        """
-        if is_public is None:
-            # preserve default value of showing only public types
-            return True
-        elif six.text_type(is_public).lower() == "all":
-            return None
-        else:
-            try:
-                return strutils.bool_from_string(is_public, strict=True)
-            except ValueError:
-                msg = _('Invalid is_public filter [%s]') % is_public
-                raise exc.HTTPBadRequest(explanation=msg)
-
     @wsgi.Controller.api_version("1.0", "2.23")
     @wsgi.action("create")
     def create(self, req, body):
@@ -175,7 +153,7 @@ class ShareTypesController(wsgi.Controller):
 
     @wsgi.Controller.api_version("2.24")  # noqa
     @wsgi.action("create")
-    def create(self, req, body):  # pylint: disable=function-redefined
+    def create(self, req, body):  # pylint: disable=function-redefined  # noqa F811
         return self._create(req, body, set_defaults=False)
 
     @wsgi.Controller.authorize('create')
@@ -229,17 +207,17 @@ class ShareTypesController(wsgi.Controller):
                 context, 'share_type.create', share_type)
 
         except exception.InvalidExtraSpec as e:
-            raise webob.exc.HTTPBadRequest(explanation=six.text_type(e))
+            raise webob.exc.HTTPBadRequest(explanation=e.message)
         except exception.ShareTypeExists as err:
             notifier_err = dict(share_types=share_type,
-                                error_message=six.text_type(err))
+                                error_message=err.message)
             self._notify_share_type_error(context, 'share_type.create',
                                           notifier_err)
 
-            raise webob.exc.HTTPConflict(explanation=six.text_type(err))
+            raise webob.exc.HTTPConflict(explanation=err.message)
         except exception.NotFound as err:
             notifier_err = dict(share_types=share_type,
-                                error_message=six.text_type(err))
+                                error_message=err.message)
             self._notify_share_type_error(context, 'share_type.create',
                                           notifier_err)
             raise webob.exc.HTTPNotFound()
@@ -258,13 +236,13 @@ class ShareTypesController(wsgi.Controller):
             self._notify_share_type_info(
                 context, 'share_type.delete', share_type)
         except exception.ShareTypeInUse as err:
-            notifier_err = dict(id=id, error_message=six.text_type(err))
+            notifier_err = dict(id=id, error_message=err.message)
             self._notify_share_type_error(context, 'share_type.delete',
                                           notifier_err)
             msg = 'Target share type is still in use.'
             raise webob.exc.HTTPBadRequest(explanation=msg)
         except exception.NotFound as err:
-            notifier_err = dict(id=id, error_message=six.text_type(err))
+            notifier_err = dict(id=id, error_message=err.message)
             self._notify_share_type_error(context, 'share_type.delete',
                                           notifier_err)
 
@@ -380,7 +358,7 @@ class ShareTypesController(wsgi.Controller):
         try:
             share_types.add_share_type_access(context, id, project)
         except exception.ShareTypeAccessExists as err:
-            raise webob.exc.HTTPConflict(explanation=six.text_type(err))
+            raise webob.exc.HTTPConflict(explanation=err.message)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -396,7 +374,7 @@ class ShareTypesController(wsgi.Controller):
         try:
             share_types.remove_share_type_access(context, id, project)
         except exception.ShareTypeAccessNotFound as err:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(err))
+            raise webob.exc.HTTPNotFound(explanation=err.message)
         return webob.Response(status_int=http_client.ACCEPTED)
 
     def _verify_if_non_public_share_type(self, context, share_type_id):
@@ -409,7 +387,7 @@ class ShareTypesController(wsgi.Controller):
                 raise webob.exc.HTTPConflict(explanation=msg)
 
         except exception.ShareTypeNotFound as err:
-            raise webob.exc.HTTPNotFound(explanation=six.text_type(err))
+            raise webob.exc.HTTPNotFound(explanation=err.message)
 
 
 def create_resource():
