@@ -13,8 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
+
 from oslo_log import log
-from six.moves import http_client
 import webob
 from webob import exc
 
@@ -24,6 +25,7 @@ from manila.api.openstack import wsgi
 from manila.api.v1 import share_manage
 from manila.api.v1 import share_unmanage
 from manila.api.v1 import shares
+from manila.api.v2 import metadata
 from manila.api.views import share_accesses as share_access_views
 from manila.api.views import share_migration as share_migration_views
 from manila.api.views import shares as share_views
@@ -31,16 +33,18 @@ from manila.common import constants
 from manila import db
 from manila import exception
 from manila.i18n import _
+from manila import policy
 from manila import share
 from manila import utils
 
 LOG = log.getLogger(__name__)
 
 
-class ShareController(shares.ShareMixin,
+class ShareController(wsgi.Controller,
+                      shares.ShareMixin,
                       share_manage.ShareManageMixin,
                       share_unmanage.ShareUnmanageMixin,
-                      wsgi.Controller,
+                      metadata.MetadataController,
                       wsgi.AdminActionsMixin):
     """The Shares API v2 controller for the OpenStack API."""
     resource_name = 'share'
@@ -65,6 +69,11 @@ class ShareController(shares.ShareMixin,
             share = self.share_api.get(context, share_id)
             snapshot = self.share_api.get_snapshot(context, snapshot_id)
 
+            if share.get('is_soft_deleted'):
+                msg = _("Share '%s cannot revert to snapshot, "
+                        "since it has been soft deleted.") % share_id
+                raise exc.HTTPForbidden(explanation=msg)
+
             # Ensure share supports reverting to a snapshot
             if not share['revert_to_snapshot_support']:
                 msg_args = {'share_id': share_id, 'snap_id': snapshot_id}
@@ -150,13 +159,13 @@ class ShareController(shares.ShareMixin,
 
             self.share_api.revert_to_snapshot(context, share, snapshot)
         except exception.ShareNotFound as e:
-            raise exc.HTTPNotFound(explanation=e)
+            raise exc.HTTPNotFound(explanation=e.msg)
         except exception.ShareSnapshotNotFound as e:
-            raise exc.HTTPBadRequest(explanation=e)
+            raise exc.HTTPBadRequest(explanation=e.msg)
         except exception.ShareSizeExceedsAvailableQuota as e:
-            raise exc.HTTPForbidden(explanation=e)
+            raise exc.HTTPForbidden(explanation=e.msg)
         except exception.ReplicationException as e:
-            raise exc.HTTPBadRequest(explanation=e)
+            raise exc.HTTPBadRequest(explanation=e.msg)
 
         return webob.Response(status_int=http_client.ACCEPTED)
 
@@ -185,6 +194,9 @@ class ShareController(shares.ShareMixin,
 
         share = body['share']
         scheduler_hints = share.pop('scheduler_hints', None)
+        if req.api_version_request < api_version.APIVersionRequest("2.67"):
+            if scheduler_hints:
+                scheduler_hints.pop('only_host', None)
         return self._create(req, body,
                             check_create_share_from_snapshot_support=True,
                             check_availability_zones_extra_spec=True,
@@ -215,11 +227,29 @@ class ShareController(shares.ShareMixin,
     @wsgi.Controller.api_version('2.0', '2.6')
     @wsgi.action('os-reset_status')
     def share_reset_status_legacy(self, req, id, body):
+        context = req.environ['manila.context']
+        try:
+            share = self.share_api.get(context, id)
+        except exception.NotFound:
+            raise exception.ShareNotFound(share_id=id)
+        if share.get('is_soft_deleted'):
+            msg = _("status cannot be reset for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
         return self._reset_status(req, id, body)
 
     @wsgi.Controller.api_version('2.7')
     @wsgi.action('reset_status')
     def share_reset_status(self, req, id, body):
+        context = req.environ['manila.context']
+        try:
+            share = self.share_api.get(context, id)
+        except exception.NotFound:
+            raise exception.ShareNotFound(share_id=id)
+        if share.get('is_soft_deleted'):
+            msg = _("status cannot be reset for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
         return self._reset_status(req, id, body)
 
     @wsgi.Controller.api_version('2.0', '2.6')
@@ -232,6 +262,60 @@ class ShareController(shares.ShareMixin,
     def share_force_delete(self, req, id, body):
         return self._force_delete(req, id, body)
 
+    @wsgi.Controller.api_version('2.69')
+    @wsgi.action('soft_delete')
+    def share_soft_delete(self, req, id, body):
+        """Soft delete a share."""
+        context = req.environ['manila.context']
+
+        LOG.debug("Soft delete share with id: %s", id, context=context)
+
+        try:
+            share = self.share_api.get(context, id)
+            self.share_api.soft_delete(context, share)
+        except exception.NotFound:
+            raise exc.HTTPNotFound()
+        except exception.InvalidShare as e:
+            raise exc.HTTPForbidden(explanation=e.msg)
+        except exception.ShareBusyException as e:
+            raise exc.HTTPForbidden(explanation=e.msg)
+        except exception.Conflict as e:
+            raise exc.HTTPConflict(explanation=e.msg)
+
+        return webob.Response(status_int=http_client.ACCEPTED)
+
+    @wsgi.Controller.api_version('2.69')
+    @wsgi.action('restore')
+    def share_restore(self, req, id, body):
+        """Restore a share from recycle bin."""
+        context = req.environ['manila.context']
+
+        LOG.debug("Restore share with id: %s", id, context=context)
+
+        try:
+            share = self.share_api.get(context, id)
+        except exception.NotFound:
+            msg = _("No share exists with ID %s.")
+            raise exc.HTTPNotFound(explanation=msg % id)
+
+        # If the share not exist in Recycle Bin, the API will return
+        # success directly.
+        is_soft_deleted = share.get('is_soft_deleted')
+        if not is_soft_deleted:
+            return webob.Response(status_int=http_client.OK)
+
+        # If the share has reached the expired time, and is been deleting,
+        # it too late to restore the share.
+        if share['status'] in [constants.STATUS_DELETING,
+                               constants.STATUS_ERROR_DELETING]:
+            msg = _("Share %s is being deleted or error deleted, "
+                    "cannot be restore.")
+            raise exc.HTTPForbidden(explanation=msg % id)
+
+        self.share_api.restore(context, share)
+
+        return webob.Response(status_int=http_client.ACCEPTED)
+
     @wsgi.Controller.api_version('2.29', experimental=True)
     @wsgi.action("migration_start")
     @wsgi.Controller.authorize
@@ -243,6 +327,12 @@ class ShareController(shares.ShareMixin,
         except exception.NotFound:
             msg = _("Share %s not found.") % id
             raise exc.HTTPNotFound(explanation=msg)
+
+        if share.get('is_soft_deleted'):
+            msg = _("Migration cannot start for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exception.InvalidShare(reason=msg)
+
         params = body.get('migration_start')
 
         if not params:
@@ -297,7 +387,7 @@ class ShareController(shares.ShareMixin,
                 new_share_network=new_share_network,
                 new_share_type=new_share_type)
         except exception.Conflict as e:
-            raise exc.HTTPConflict(explanation=e)
+            raise exc.HTTPConflict(explanation=e.msg)
 
         return webob.Response(status_int=return_code)
 
@@ -351,6 +441,15 @@ class ShareController(shares.ShareMixin,
     @wsgi.action("reset_task_state")
     @wsgi.Controller.authorize
     def reset_task_state(self, req, id, body):
+        context = req.environ['manila.context']
+        try:
+            share = self.share_api.get(context, id)
+        except exception.NotFound:
+            raise exception.ShareNotFound(share_id=id)
+        if share.get('is_soft_deleted'):
+            msg = _("task state cannot be reset for share '%s' "
+                    "since it has been soft deleted.") % id
+            raise exc.HTTPForbidden(explanation=msg)
         return self._reset_status(req, id, body, status_attr='task_state')
 
     @wsgi.Controller.api_version('2.0', '2.6')
@@ -478,6 +577,9 @@ class ShareController(shares.ShareMixin,
         if req.api_version_request < api_version.APIVersionRequest("2.42"):
             req.GET.pop('with_count', None)
 
+        if req.api_version_request < api_version.APIVersionRequest("2.69"):
+            req.GET.pop('is_soft_deleted', None)
+
         return self._get_shares(req, is_detail=False)
 
     @wsgi.Controller.api_version("2.0")
@@ -492,8 +594,98 @@ class ShareController(shares.ShareMixin,
             req.GET.pop('description~', None)
             req.GET.pop('description', None)
 
+        if req.api_version_request < api_version.APIVersionRequest("2.69"):
+            req.GET.pop('is_soft_deleted', None)
+
         return self._get_shares(req, is_detail=True)
 
+    def _validate_metadata_for_update(self, req, share_id, metadata,
+                                      delete=True):
+        admin_metadata_ignore_keys = (
+            constants.AdminOnlyMetadata.SCHEDULER_FILTERS
+        )
+        context = req.environ['manila.context']
+        if set(metadata).intersection(set(admin_metadata_ignore_keys)):
+            try:
+                policy.check_policy(
+                    context, 'share', 'update_admin_only_metadata')
+            except exception.PolicyNotAuthorized:
+                msg = _("Cannot set or update admin only metadata.")
+                LOG.exception(msg)
+                raise exc.HTTPForbidden(explanation=msg)
+            admin_metadata_ignore_keys = []
+
+        current_share_metadata = db.share_metadata_get(context, share_id)
+        if delete:
+            _metadata = metadata
+            for key in admin_metadata_ignore_keys:
+                if key in current_share_metadata:
+                    _metadata[key] = current_share_metadata[key]
+        else:
+            metadata_copy = metadata.copy()
+            for key in admin_metadata_ignore_keys:
+                metadata_copy.pop(key, None)
+            _metadata = current_share_metadata.copy()
+            _metadata.update(metadata_copy)
+
+        return _metadata
+
+    # NOTE: (ashrod98) original metadata method and policy overrides
+    @wsgi.Controller.api_version("2.0")
+    @wsgi.Controller.authorize("get_share_metadata")
+    def index_metadata(self, req, resource_id):
+        """Returns the list of metadata for a given share."""
+        return self._index_metadata(req, resource_id)
+
+    @wsgi.Controller.api_version("2.0")
+    @wsgi.Controller.authorize("update_share_metadata")
+    def create_metadata(self, req, resource_id, body):
+        if not self.is_valid_body(body, 'metadata'):
+            expl = _('Malformed request body')
+            raise exc.HTTPBadRequest(explanation=expl)
+        _metadata = self._validate_metadata_for_update(req, resource_id,
+                                                       body['metadata'],
+                                                       delete=False)
+        body['metadata'] = _metadata
+        return self._create_metadata(req, resource_id, body)
+
+    @wsgi.Controller.api_version("2.0")
+    @wsgi.Controller.authorize("update_share_metadata")
+    def update_all_metadata(self, req, resource_id, body):
+        if not self.is_valid_body(body, 'metadata'):
+            expl = _('Malformed request body')
+            raise exc.HTTPBadRequest(explanation=expl)
+        _metadata = self._validate_metadata_for_update(req, resource_id,
+                                                       body['metadata'])
+        body['metadata'] = _metadata
+        return self._update_all_metadata(req, resource_id, body)
+
+    @wsgi.Controller.api_version("2.0")
+    @wsgi.Controller.authorize("update_share_metadata")
+    def update_metadata_item(self, req, resource_id, body, key):
+        if not self.is_valid_body(body, 'meta'):
+            expl = _('Malformed request body')
+            raise exc.HTTPBadRequest(explanation=expl)
+        _metadata = self._validate_metadata_for_update(req, resource_id,
+                                                       body['metadata'],
+                                                       delete=False)
+        body['metadata'] = _metadata
+        return self._update_metadata_item(req, resource_id, body, key)
+
+    @wsgi.Controller.api_version("2.0")
+    @wsgi.Controller.authorize("get_share_metadata")
+    def show_metadata(self, req, resource_id, key):
+        return self._show_metadata(req, resource_id, key)
+
+    @wsgi.Controller.api_version("2.0")
+    @wsgi.Controller.authorize("delete_share_metadata")
+    def delete_metadata(self, req, resource_id, key):
+        context = req.environ['manila.context']
+        if key in constants.AdminOnlyMetadata.SCHEDULER_FILTERS:
+            policy.check_policy(context, 'share',
+                                'update_admin_only_metadata')
+        return self._delete_metadata(req, resource_id, key)
+
 
 def create_resource():
     return wsgi.Resource(ShareController())
