@@ -21,7 +21,9 @@ class ViewBuilder(common.ViewBuilder):
 
     _collection_name = 'share_networks'
     _detail_version_modifiers = ["add_gateway", "add_mtu", "add_nova_net_id",
-                                 "add_subnets"]
+                                 "add_subnets",
+                                 "add_status_and_sec_service_update_fields",
+                                 "add_network_allocation_update_support_field"]
 
     def build_share_network(self, request, share_network):
         """View of a share network."""
@@ -35,6 +37,35 @@ class ViewBuilder(common.ViewBuilder):
                     request, share_network, is_detail)
                  for share_network in share_networks]}
 
+    def build_security_service_update_check(self, request, params, result):
+        """View of security service add or update check."""
+        context = request.environ['manila.context']
+        requested_operation = {
+            'operation': ('update_security_service'
+                          if params.get('current_service_id')
+                          else 'add_security_service'),
+            'current_security_service': params.get('current_service_id'),
+            'new_security_service': (params.get('new_service_id') or
+                                     params.get('security_service_id'))
+        }
+        view = {
+            'compatible': result['compatible'],
+            'requested_operation': requested_operation,
+        }
+        if context.is_admin:
+            view['hosts_check_result'] = result['hosts_check_result']
+        return view
+
+    def build_share_network_subnet_create_check(self, request, result):
+        """View of share network subnet create check."""
+        context = request.environ['manila.context']
+        view = {
+            'compatible': result['compatible'],
+        }
+        if context.is_admin:
+            view['hosts_check_result'] = result['hosts_check_result']
+        return view
+
     def _update_share_network_info(self, request, share_network):
         for sns in share_network.get('share_network_subnets') or []:
             if sns.get('is_default') and sns.get('is_default') is True:
@@ -108,3 +139,16 @@ class ViewBuilder(common.ViewBuilder):
     @common.ViewBuilder.versioned_method("1.0", "2.25")
     def add_nova_net_id(self, context, network_dict, network):
         network_dict['nova_net_id'] = None
+
+    @common.ViewBuilder.versioned_method("2.63")
+    def add_status_and_sec_service_update_fields(
+            self, context, network_dict, network):
+        network_dict['status'] = network.get('status')
+        network_dict['security_service_update_support'] = network.get(
+            'security_service_update_support')
+
+    @common.ViewBuilder.versioned_method("2.70")
+    def add_network_allocation_update_support_field(
+            self, context, network_dict, network):
+        network_dict['network_allocation_update_support'] = network.get(
+            'network_allocation_update_support')
