@@ -294,3 +294,13 @@ class ExtraSpecs(object):
     }
 
     REPLICATION_TYPES = ('writable', 'readable', 'dr')
+
+
+class AdminOnlyMetadata(object):
+    AFFINITY_KEY = "__affinity_same_host"
+    ANTI_AFFINITY_KEY = "__affinity_different_host"
+
+    SCHEDULER_FILTERS = (
+        AFFINITY_KEY,
+        ANTI_AFFINITY_KEY
+    )
