@@ -16,12 +16,13 @@
 Handles all requests to Nova.
 """
 
+import functools
+
 from keystoneauth1 import loading as ks_loading
 from novaclient import client as nova_client
 from novaclient import exceptions as nova_exception
 from novaclient import utils
 from oslo_config import cfg
-import six
 
 from manila.common import client_auth
 from manila.common.config import core_opts
@@ -36,8 +37,6 @@ AUTH_OBJ = None
 nova_opts = [
     cfg.StrOpt('api_microversion',
                default='2.10',
-               deprecated_group="DEFAULT",
-               deprecated_name="nova_api_microversion",
                help='Version of Nova API to be used.'),
     cfg.StrOpt('endpoint_type',
                default='publicURL',
@@ -46,28 +45,11 @@ nova_opts = [
                help='Region name for connecting to nova.'),
     ]
 
-# These fallback options can be removed in/after 9.0.0 (Train)
-deprecated_opts = {
-    'cafile': [
-        cfg.DeprecatedOpt('ca_certificates_file', group="DEFAULT"),
-        cfg.DeprecatedOpt('ca_certificates_file', group=NOVA_GROUP),
-        cfg.DeprecatedOpt('nova_ca_certificates_file', group="DEFAULT"),
-        cfg.DeprecatedOpt('nova_ca_certificates_file', group=NOVA_GROUP),
-    ],
-    'insecure': [
-        cfg.DeprecatedOpt('api_insecure', group="DEFAULT"),
-        cfg.DeprecatedOpt('api_insecure', group=NOVA_GROUP),
-        cfg.DeprecatedOpt('nova_api_insecure', group="DEFAULT"),
-        cfg.DeprecatedOpt('nova_api_insecure', group=NOVA_GROUP),
-    ],
-}
-
 CONF = cfg.CONF
 CONF.register_opts(core_opts)
 CONF.register_opts(nova_opts, NOVA_GROUP)
 ks_loading.register_session_conf_options(CONF,
-                                         NOVA_GROUP,
-                                         deprecated_opts=deprecated_opts)
+                                         NOVA_GROUP)
 ks_loading.register_auth_conf_options(CONF, NOVA_GROUP)
 
 
@@ -119,7 +101,7 @@ def translate_server_exception(method):
     Note: keeps its traceback intact.
     """
 
-    @six.wraps(method)
+    @functools.wraps(method)
     def wrapper(self, ctx, instance_id, *args, **kwargs):
         try:
             res = method(self, ctx, instance_id, *args, **kwargs)
@@ -128,7 +110,7 @@ def translate_server_exception(method):
             if isinstance(e, nova_exception.NotFound):
                 raise exception.InstanceNotFound(instance_id=instance_id)
             elif isinstance(e, nova_exception.BadRequest):
-                raise exception.InvalidInput(reason=six.text_type(e))
+                raise exception.InvalidInput(reason=str(e))
             else:
                 raise exception.ManilaException(e)
 
