@@ -15,8 +15,9 @@
 import os
 
 from oslo_log import log
-import six
 
+from manila import exception
+from manila.i18n import _
 from manila import utils
 
 LOG = log.getLogger(__name__)
@@ -24,7 +25,7 @@ LOG = log.getLogger(__name__)
 
 class Copy(object):
 
-    def __init__(self, src, dest, ignore_list):
+    def __init__(self, src, dest, ignore_list, check_hash=False):
         self.src = src
         self.dest = dest
         self.total_size = 0
@@ -34,37 +35,47 @@ class Copy(object):
         self.current_copy = None
         self.ignore_list = ignore_list
         self.cancelled = False
+        self.initialized = False
+        self.completed = False
+        self.check_hash = check_hash
 
     def get_progress(self):
 
-        if self.current_copy is not None:
-
-            try:
-                size, err = utils.execute("stat", "-c", "%s",
-                                          self.current_copy['file_path'],
-                                          run_as_root=True)
-                size = int(size)
-            except utils.processutils.ProcessExecutionError:
-                size = 0
-
-            total_progress = 0
-            if self.total_size > 0:
-                total_progress = self.current_size * 100 / self.total_size
-            current_file_progress = 0
-            if self.current_copy['size'] > 0:
-                current_file_progress = size * 100 / self.current_copy['size']
-            current_file_path = self.current_copy['file_path']
-
-            progress = {
-                'total_progress': total_progress,
-                'current_file_path': current_file_path,
-                'current_file_progress': current_file_progress
-            }
-
-            return progress
-        else:
+        # Empty share or empty contents
+        if self.completed and self.total_size == 0:
             return {'total_progress': 100}
 
+        if not self.initialized or self.current_copy is None:
+            return {'total_progress': 0}
+
+        try:
+            size, err = utils.execute("stat", "-c", "%s",
+                                      self.current_copy['file_path'],
+                                      run_as_root=True)
+            size = int(size)
+        except utils.processutils.ProcessExecutionError:
+            size = 0
+
+        current_file_progress = 0
+        if self.current_copy['size'] > 0:
+            current_file_progress = size * 100 / self.current_copy['size']
+        current_file_path = self.current_copy['file_path']
+
+        total_progress = 0
+        if self.total_size > 0:
+            if current_file_progress == 100:
+                size = 0
+            total_progress = int((self.current_size + size) *
+                                 100 / self.total_size)
+
+        progress = {
+            'total_progress': total_progress,
+            'current_file_path': current_file_path,
+            'current_file_progress': current_file_progress
+        }
+
+        return progress
+
     def cancel(self):
 
         self.cancelled = True
@@ -72,10 +83,12 @@ class Copy(object):
     def run(self):
 
         self.get_total_size(self.src)
+        self.initialized = True
         self.copy_data(self.src)
         self.copy_stats(self.src)
+        self.completed = True
 
-        LOG.info(six.text_type(self.get_progress()))
+        LOG.info(self.get_progress())
 
     def get_total_size(self, path):
         if self.cancelled:
@@ -127,12 +140,18 @@ class Copy(object):
                 self.current_copy = {'file_path': dest_item,
                                      'size': int(size)}
 
-                utils.execute("cp", "-P", "--preserve=all", src_item,
-                              dest_item, run_as_root=True)
+                self._copy_and_validate(src_item, dest_item)
 
                 self.current_size += int(size)
+                LOG.info(self.get_progress())
 
-                LOG.info(six.text_type(self.get_progress()))
+    @utils.retry(retry_param=exception.ShareDataCopyFailed, retries=2)
+    def _copy_and_validate(self, src_item, dest_item):
+        utils.execute("cp", "-P", "--preserve=all", src_item,
+                      dest_item, run_as_root=True)
+
+        if self.check_hash:
+            _validate_item(src_item, dest_item)
 
     def copy_stats(self, path):
         if self.cancelled:
@@ -158,3 +177,13 @@ class Copy(object):
                               run_as_root=True)
                 utils.execute("chown", "--reference=%s" % src_item, dest_item,
                               run_as_root=True)
+
+
+def _validate_item(src_item, dest_item):
+    src_sum, err = utils.execute(
+        "sha256sum", "%s" % src_item, run_as_root=True)
+    dest_sum, err = utils.execute(
+        "sha256sum", "%s" % dest_item, run_as_root=True)
+    if src_sum.split()[0] != dest_sum.split()[0]:
+        msg = _("Data corrupted while copying. Aborting data copy.")
+        raise exception.ShareDataCopyFailed(reason=msg)
