@@ -389,9 +389,9 @@ def share_update(context, share_id, values):
     return IMPL.share_update(context, share_id, values)
 
 
-def share_get(context, share_id):
+def share_get(context, share_id, **kwargs):
     """Get share by id."""
-    return IMPL.share_get(context, share_id)
+    return IMPL.share_get(context, share_id, **kwargs)
 
 
 def share_get_all(context, filters=None, sort_key=None, sort_dir=None):
@@ -451,6 +451,15 @@ def share_get_all_by_share_server(context, share_server_id, filters=None,
         sort_dir=sort_dir)
 
 
+def get_shares_in_recycle_bin_by_share_server(
+        context, share_server_id, filters=None,
+        sort_key=None, sort_dir=None):
+    """Returns all shares in recycle bin with given share server ID."""
+    return IMPL.get_shares_in_recycle_bin_by_share_server(
+        context, share_server_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
+
+
 def share_get_all_by_share_server_with_count(
         context, share_server_id, filters=None, sort_key=None, sort_dir=None):
     """Returns all shares with given share server ID."""
@@ -459,11 +468,29 @@ def share_get_all_by_share_server_with_count(
         sort_dir=sort_dir)
 
 
+def get_shares_in_recycle_bin_by_network(
+        context, share_network_id, filters=None,
+        sort_key=None, sort_dir=None):
+    """Returns all shares in recycle bin with given share network ID."""
+    return IMPL.get_shares_in_recycle_bin_by_network(
+        context, share_network_id, filters=filters, sort_key=sort_key,
+        sort_dir=sort_dir)
+
+
 def share_delete(context, share_id):
     """Delete share."""
     return IMPL.share_delete(context, share_id)
 
 
+def share_soft_delete(context, share_id):
+    """Soft delete share."""
+    return IMPL.share_soft_delete(context, share_id)
+
+
+def share_restore(context, share_id):
+    """Restore share."""
+    return IMPL.share_restore(context, share_id)
+
 ###################
 
 
@@ -778,17 +805,17 @@ def share_metadata_get_item(context, share_id, key):
 
 def share_metadata_delete(context, share_id, key):
     """Delete the given metadata item."""
-    IMPL.share_metadata_delete(context, share_id, key)
+    return IMPL.share_metadata_delete(context, share_id, key)
 
 
 def share_metadata_update(context, share, metadata, delete):
     """Update metadata if it exists, otherwise create it."""
-    IMPL.share_metadata_update(context, share, metadata, delete)
+    return IMPL.share_metadata_update(context, share, metadata, delete)
 
 
 def share_metadata_update_item(context, share_id, item):
     """update meta item containing key and value for given share."""
-    IMPL.share_metadata_update_item(context, share_id, item)
+    return IMPL.share_metadata_update_item(context, share_id, item)
 
 
 ###################
@@ -957,29 +984,45 @@ def share_network_subnet_get(context, network_subnet_id, session=None):
                                          session=session)
 
 
+def share_network_subnet_get_all_with_same_az(context, network_subnet_id,
+                                              session=None):
+    """Get requested az share network subnets DB record."""
+    return IMPL.share_network_subnet_get_all_with_same_az(
+        context, network_subnet_id, session=session)
+
+
 def share_network_subnet_get_all(context):
     """Get all share network subnet DB record."""
     return IMPL.share_network_subnet_get_all(context)
 
 
-def share_network_subnet_get_by_availability_zone_id(context, share_network_id,
-                                                     availability_zone_id):
-    """Get a share network subnet DB record.
+def share_network_subnets_get_all_by_availability_zone_id(
+        context, share_network_id, availability_zone_id,
+        fallback_to_default=True):
+    """Get the share network subnets DB record in a given AZ.
 
-    This method returns a subnet DB record for a given share network id and
-    an availability zone. If the 'availability_zone_id' is 'None', a record may
-    be returned and it will represent the default share network subnet.
-    Be aware that if there is no subnet for a specific availability zone id,
-    this method will return the default share network subnet, if it exists.
+    This method returns list of subnets DB record for a given share network id
+    and an availability zone. If the 'availability_zone_id' is 'None', a
+    record may be returned and it will represent the default share network
+    subnets. If there is no subnet for a specific availability zone id and
+    "fallback_to_default" is True, this method will return the default share
+    network subnets, if it exists.
     """
-    return IMPL.share_network_subnet_get_by_availability_zone_id(
-        context, share_network_id, availability_zone_id)
+    return IMPL.share_network_subnets_get_all_by_availability_zone_id(
+        context, share_network_id, availability_zone_id,
+        fallback_to_default=fallback_to_default)
 
 
-def share_network_subnet_get_default_subnet(context, share_network_id):
-    """Get the default share network subnet DB record."""
-    return IMPL.share_network_subnet_get_default_subnet(context,
-                                                        share_network_id)
+def share_network_subnet_get_default_subnets(context, share_network_id):
+    """Get the default share network subnets DB records."""
+    return IMPL.share_network_subnet_get_default_subnets(context,
+                                                         share_network_id)
+
+
+def share_network_subnet_get_all_by_share_server_id(context, share_server_id):
+    """Get the subnets that are being used by the share server."""
+    return IMPL.share_network_subnet_get_all_by_share_server_id(
+        context, share_server_id)
 
 
 ##################
@@ -1008,10 +1051,12 @@ def network_allocation_get(context, id, session=None, read_deleted=None):
 
 
 def network_allocations_get_for_share_server(context, share_server_id,
-                                             session=None, label=None):
+                                             session=None, label=None,
+                                             subnet_id=None):
     """Get network allocations for share server."""
     return IMPL.network_allocations_get_for_share_server(
-        context, share_server_id, label=label, session=session)
+        context, share_server_id, label=label, session=session,
+        subnet_id=subnet_id)
 
 
 def network_allocations_get_by_ip_address(context, ip_address):
@@ -1050,6 +1095,7 @@ def share_server_search_by_identifier(context, identifier, session=None):
 
 def share_server_get_all_by_host_and_share_subnet_valid(context, host,
                                                         share_subnet_id,
+                                                        server_status=None,
                                                         session=None):
     """Get share server DB records by host and share net not error."""
     return IMPL.share_server_get_all_by_host_and_share_subnet_valid(
@@ -1077,6 +1123,11 @@ def share_server_get_all_unused_deletable(context, host, updated_before):
                                                       updated_before)
 
 
+def get_all_expired_shares(context):
+    """Get all expired share DB records."""
+    return IMPL.get_all_expired_shares(context)
+
+
 def share_server_backend_details_set(context, share_server_id, server_details):
     """Create DB record with backend details."""
     return IMPL.share_server_backend_details_set(context, share_server_id,
