@@ -26,7 +26,6 @@ import re
 from oslo_concurrency import processutils
 from oslo_config import cfg
 from oslo_log import log
-import six
 import webob.exc
 
 from manila.i18n import _
@@ -82,7 +81,7 @@ class ManilaException(Exception):
                 pass
         for k, v in self.kwargs.items():
             if isinstance(v, Exception):
-                self.kwargs[k] = six.text_type(v)
+                self.kwargs[k] = str(v)
 
         if not message:
             try:
@@ -101,7 +100,7 @@ class ManilaException(Exception):
                     # at least get the core message out if something happened
                     message = self.message
         elif isinstance(message, Exception):
-            message = six.text_type(message)
+            message = str(message)
 
         if re.match(r'.*[^\.]\.\.$', message):
             message = message[:-1]
@@ -233,6 +232,11 @@ class ShareNetworkSubnetNotFound(NotFound):
                 " found.")
 
 
+class ShareNetworkSubnetNotFoundByShareServer(NotFound):
+    message = _("Share network subnet could not be found by "
+                "%(share_server_id)s.")
+
+
 class ShareServerNotFound(NotFound):
     message = _("Share server %(share_server_id)s could not be found.")
 
@@ -242,6 +246,11 @@ class ShareServerNotFoundByFilters(ShareServerNotFound):
                 "filters: %(filters_description)s.")
 
 
+class AllocationsNotFoundForShareServer(NotFound):
+    message = _("No allocations found for the share server "
+                "%(share_server_id)s on the subnet.")
+
+
 class InvalidShareNetwork(Invalid):
     message = _("Invalid share network: %(reason)s")
 
@@ -589,7 +598,7 @@ class UnmanageInvalidShareSnapshot(InvalidShareSnapshot):
                 "invalid share snapshot: %(reason)s.")
 
 
-class ShareMetadataNotFound(NotFound):
+class MetadataItemNotFound(NotFound):
     message = _("Metadata item is not found.")
 
 
