@@ -14,7 +14,6 @@
 #    under the License.
 
 import netaddr
-import six
 
 from manila.i18n import _
 from manila import utils
@@ -117,7 +116,7 @@ class IPWrapper(SubProcessBase):
     @classmethod
     def get_namespaces(cls):
         output = cls._execute('', 'netns', ('list',))
-        return [l.strip() for l in output.split('\n')]
+        return [ns.strip() for ns in output.split('\n')]
 
 
 class IPDevice(SubProcessBase):
@@ -462,7 +461,7 @@ def device_exists(device_name, namespace=None):
     try:
         address = IPDevice(device_name, namespace).link.address
     except Exception as e:
-        if 'does not exist' in six.text_type(e):
+        if 'does not exist' in str(e):
             return False
         raise
     return bool(address)
