@@ -29,6 +29,8 @@ import manila.data.helper
 import manila.db.api
 import manila.db.base
 import manila.exception
+import manila.image
+import manila.image.glance
 import manila.message.api
 import manila.network
 import manila.network.linux.interface
@@ -73,6 +75,7 @@ import manila.share.drivers.lvm
 import manila.share.drivers.maprfs.maprfs_native
 import manila.share.drivers.netapp.options
 import manila.share.drivers.nexenta.options
+import manila.share.drivers.purestorage.flashblade
 import manila.share.drivers.qnap.qnap
 import manila.share.drivers.quobyte.quobyte
 import manila.share.drivers.service_instance
@@ -104,6 +107,7 @@ _global_opt_lists = [
     manila.db.api.db_opts,
     [manila.db.base.db_driver_opt],
     manila.exception.exc_log_opts,
+    manila.image._glance_opts,
     manila.message.api.messages_opts,
     manila.network.linux.interface.OPTS,
     manila.network.network_opts,
@@ -119,7 +123,6 @@ _global_opt_lists = [
     manila.network.neutron.neutron_network_plugin.
     neutron_binding_profile_opts,
     manila.network.standalone_network_plugin.standalone_network_plugin_opts,
-    manila.quota.quota_opts,
     manila.scheduler.drivers.base.scheduler_driver_opts,
     manila.scheduler.host_manager.host_manager_opts,
     [manila.scheduler.manager.scheduler_driver_opt],
@@ -168,6 +171,9 @@ _global_opt_lists = [
     manila.share.drivers.nexenta.options.nexenta_connection_opts,
     manila.share.drivers.nexenta.options.nexenta_dataset_opts,
     manila.share.drivers.nexenta.options.nexenta_nfs_opts,
+    manila.share.drivers.purestorage.flashblade.flashblade_auth_opts,
+    manila.share.drivers.purestorage.flashblade.flashblade_extra_opts,
+    manila.share.drivers.purestorage.flashblade.flashblade_connection_opts,
     manila.share.drivers.qnap.qnap.qnap_manila_opts,
     manila.share.drivers.quobyte.quobyte.quobyte_manila_share_opts,
     manila.share.drivers.service_instance.common_opts,
@@ -192,10 +198,15 @@ _opts = [
      list(itertools.chain(manila.compute.nova.nova_opts))),
     (manila.network.neutron.api.NEUTRON_GROUP,
      list(itertools.chain(manila.network.neutron.api.neutron_opts))),
+    (manila.image.glance.GLANCE_GROUP,
+     list(itertools.chain(manila.image.glance.glance_opts))),
+    (manila.quota.QUOTA_GROUP,
+     list(itertools.chain(manila.quota.quota_opts))),
 ]
 
 _opts.extend(manila.network.neutron.api.list_opts())
 _opts.extend(manila.compute.nova.list_opts())
+_opts.extend(manila.image.glance.list_opts())
 _opts.extend(manila.volume.cinder.list_opts())
 
 
