@@ -20,6 +20,7 @@ import sys
 
 from oslo_config import cfg
 from oslo_log import log as logging
+from oslo_policy import opts
 from oslo_policy import policy
 from oslo_utils import excutils
 
@@ -31,6 +32,13 @@ LOG = logging.getLogger(__name__)
 _ENFORCER = None
 
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
+
 def reset():
     global _ENFORCER
     if _ENFORCER:
@@ -38,16 +46,16 @@ def reset():
         _ENFORCER = None
 
 
-def init(rules=None, use_conf=True):
+def init(rules=None, use_conf=True, suppress_deprecation_warnings=False):
     """Init an Enforcer class.
 
         :param policy_file: Custom policy file to use, if none is specified,
                           `CONF.policy_file` will be used.
         :param rules: Default dictionary / Rules to use. It will be
                     considered just in the first instantiation.
-        :param default_rule: Default rule to use, CONF.default_rule will
-                           be used if none is specified.
         :param use_conf: Whether to load rules from config file.
+        :param suppress_deprecation_warnings: Whether to suppress policy
+                                            deprecation warnings.
     """
 
     global _ENFORCER
@@ -55,12 +63,28 @@ def init(rules=None, use_conf=True):
         _ENFORCER = policy.Enforcer(CONF,
                                     rules=rules,
                                     use_conf=use_conf)
+
+        # NOTE(gouthamr): Explicitly disable the warnings for policies
+        # changing their default check_str. During
+        # secure-rbac / policy-defaults-refresh work, all the policy
+        # defaults have been changed and warning for each policy started
+        # filling the log limits for various tools. Once we move to new
+        # defaults only world then we can enable these warning again.
+        _ENFORCER.suppress_default_change_warnings = True
+        # Suppressing deprecation warnings is fine for tests. However we
+        # won't do it by default
+        _ENFORCER.suppress_deprecation_warnings = suppress_deprecation_warnings
+
         register_rules(_ENFORCER)
 
 
 def enforce(context, action, target, do_raise=True):
     """Verifies that the action is valid on the target in this context.
 
+       **IMPORTANT** ONLY for use in API extensions. This method ignores
+       unregistered rules and applies a default rule on them; there should
+       be no unregistered rules in first party manila APIs.
+
        :param context: manila context
        :param action: string representing the action to be checked,
            this should be colon separated for clarity.
@@ -79,15 +103,16 @@ def enforce(context, action, target, do_raise=True):
 
     """
     init()
-    if not isinstance(context, dict):
-        context = context.to_dict()
 
-    # Add the exception arguments if asked to do a raise
-    extra = {}
-    if do_raise:
-        extra.update(exc=exception.PolicyNotAuthorized, action=action,
-                     do_raise=do_raise)
-    return _ENFORCER.enforce(action, target, context, **extra)
+    try:
+        return _ENFORCER.enforce(action,
+                                 target,
+                                 context,
+                                 do_raise=do_raise,
+                                 exc=exception.PolicyNotAuthorized,
+                                 action=action)
+    except policy.InvalidScope:
+        raise exception.PolicyNotAuthorized(action=action)
 
 
 def set_rules(rules, overwrite=True, use_conf=False):
@@ -159,32 +184,43 @@ def authorize(context, action, target, do_raise=True, exc=None):
            do_raise is False.
     """
     init()
-    credentials = context.to_policy_values()
     if not exc:
         exc = exception.PolicyNotAuthorized
+    target = target or default_target(context)
+
     try:
-        result = _ENFORCER.authorize(action, target, credentials,
+        result = _ENFORCER.authorize(action, target, context,
                                      do_raise=do_raise, exc=exc, action=action)
     except policy.PolicyNotRegistered:
         with excutils.save_and_reraise_exception():
             LOG.exception('Policy not registered')
+    except policy.InvalidScope:
+        if do_raise:
+            raise exception.PolicyNotAuthorized(action=action)
+        else:
+            return False
     except Exception:
         with excutils.save_and_reraise_exception():
+            msg_args = {
+                'action': action,
+                'credentials': context.to_policy_values(),
+            }
             LOG.debug('Policy check for %(action)s failed with credentials '
-                      '%(credentials)s',
-                      {'action': action, 'credentials': credentials})
+                      '%(credentials)s', msg_args)
     return result
 
 
+def default_target(context):
+    return {'project_id': context.project_id, 'user_id': context.user_id}
+
+
 def check_is_admin(context):
     """Whether or not user is admin according to policy setting.
 
     """
-    init()
-
-    credentials = context.to_policy_values()
-    target = credentials
-    return _ENFORCER.authorize('context_is_admin', target, credentials)
+    # the target is user-self
+    target = default_target(context)
+    return authorize(context, 'context_is_admin', target, do_raise=False)
 
 
 def wrap_check_policy(resource):
@@ -200,10 +236,6 @@ def wrap_check_policy(resource):
 
 
 def check_policy(context, resource, action, target_obj=None, do_raise=True):
-    target = {
-        'project_id': context.project_id,
-        'user_id': context.user_id,
-    }
-    target.update(target_obj or {})
+    target = target_obj or default_target(context)
     _action = '%s:%s' % (resource, action)
     return authorize(context, _action, target, do_raise=do_raise)
