@@ -56,9 +56,9 @@ class EvalConstant(object):
         except ValueError:
             try:
                 result = float(result)
-            except ValueError:
-                if isinstance(result, str):
-                    result = result.replace('"', '').replace('\'', '')
+            except ValueError as e:
+                msg = _("ValueError: %s") % e
+                raise exception.EvaluatorParseException(reason=msg)
 
         return result
 
@@ -233,10 +233,9 @@ def _def_parser():
     Combine = pyparsing.Combine
     Forward = pyparsing.Forward
     nums = pyparsing.nums
-    quoted_string = pyparsing.quotedString
     oneOf = pyparsing.oneOf
     opAssoc = pyparsing.opAssoc
-    operatorPrecedence = pyparsing.operatorPrecedence
+    infixNotation = pyparsing.infixNotation
     Word = pyparsing.Word
 
     integer = Word(nums)
@@ -245,7 +244,7 @@ def _def_parser():
     number = real | integer
     expr = Forward()
     fn = Word(alphas + '_' + '.')
-    operand = number | variable | fn | quoted_string
+    operand = number | variable | fn
 
     signop = oneOf('+ -')
     addop = oneOf('+ -')
@@ -257,7 +256,7 @@ def _def_parser():
     negateop = oneOf('NOT not !')
 
     operand.setParseAction(EvalConstant)
-    expr = operatorPrecedence(operand, [
+    expr = infixNotation(operand, [
         (fn, 1, opAssoc.RIGHT, EvalFunction),
         ("^", 2, opAssoc.RIGHT, EvalPowerOp),
         (signop, 1, opAssoc.RIGHT, EvalSignOp),
