@@ -443,9 +443,8 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             "sub_name": share["id"],
             "size": size,
             "namespace_isolated": True,
-            "mode": self._cephfs_volume_mode
+            "mode": self._cephfs_volume_mode,
         }
-
         if share['share_group_id'] is not None:
             argdict.update({"group_name": share["share_group_id"]})
 
@@ -519,14 +518,8 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             share_server=share_server)
 
     def ensure_share(self, context, share, share_server=None):
-        try:
-            export_location = self._get_export_locations(share)
-        except exception.ShareBackendException as e:
-            if 'does not exist' in str(e).lower():
-                raise exception.ShareResourceNotFound(share_id=share['id'])
-            raise
-
-        return export_location
+        # Creation is idempotent
+        return self.create_share(context, share, share_server)
 
     def extend_share(self, share, new_size, share_server=None):
         # resize FS subvolume/share
@@ -853,16 +846,7 @@ class NativeProtocolHelper(ganesha.NASHelperBase):
         if share["share_group_id"] is not None:
             argdict.update({"group_name": share["share_group_id"]})
 
-        try:
-            rados_command(self.rados_client,
-                          "fs subvolume deauthorize",
-                          argdict)
-        except exception.ShareBackendException as e:
-            if "doesn't exist" in e.msg.lower():
-                LOG.warning(f"%{access['access_to']} did not have access to "
-                            f"share {share['id']}.")
-                return
-            raise e
+        rados_command(self.rados_client, "fs subvolume deauthorize", argdict)
         rados_command(self.rados_client, "fs subvolume evict", argdict)
 
     def update_access(self, context, share, access_rules, add_rules,
@@ -1055,8 +1039,7 @@ class NFSProtocolHelper(ganesha.GaneshaNASHelper2):
         return {
             'Name': 'Ceph',
             'User_Id': ceph_auth_id,
-            'Secret_Access_Key': auth_result,
-            'Filesystem': self.volname
+            'Secret_Access_Key': auth_result
         }
 
     def _cleanup_fsal_hook(self, base, share, access):
