@@ -16,7 +16,6 @@
 
 import copy
 import random
-import six
 
 from oslo_config import cfg
 from oslo_log import log
@@ -43,8 +42,9 @@ from manila import utils
     3.2.0 - Wrong format of export locations (bug #1871999)
     3.3.0 - Victoria release
     3.4.0 - Wallaby release
+    3.5.0 - Xena release
 """
-VERSION = "3.4.0"
+VERSION = "3.5.0"
 
 LOG = log.getLogger(__name__)
 
@@ -735,7 +735,7 @@ class PowerMaxStorageConnection(driver.StorageConnection):
                 }
                 if ip_version == 6:
                     interface['ip_version'] = ip_version
-                    interface['net_mask'] = six.text_type(
+                    interface['net_mask'] = str(
                         utils.cidr_to_prefixlen(
                             network_info['cidr']))
                 else:
