@@ -42,10 +42,11 @@ from manila import utils
      7.0.1 - Fix parsing management IPv6 address
      7.0.2 - Bugfix: failed to delete CIFS share if wrong access was set
      8.0.0 - Supports manage/unmanage share server/share/snapshot
-     8.0.1 - Bugfix: remove enable ace process when creating cifs share
+     9.0.0 - Implements default filter function
+     9.0.1 - Bugfix: remove enable ace process when creating cifs share
 """
 
-VERSION = "8.0.1"
+VERSION = "9.0.1"
 
 LOG = log.getLogger(__name__)
 SUPPORTED_NETWORK_TYPES = (None, 'flat', 'vlan')
@@ -53,26 +54,21 @@ SUPPORTED_NETWORK_TYPES = (None, 'flat', 'vlan')
 UNITY_OPTS = [
     cfg.StrOpt('unity_server_meta_pool',
                required=True,
-               deprecated_name='emc_nas_server_pool',
                help='Pool to persist the meta-data of NAS server.'),
     cfg.ListOpt('unity_share_data_pools',
-                deprecated_name='emc_nas_pool_names',
                 help='Comma separated list of pools that can be used to '
                      'persist share data.'),
     cfg.ListOpt('unity_ethernet_ports',
-                deprecated_name='emc_interface_ports',
                 help='Comma separated list of ports that can be used for '
                      'share server interfaces. Members of the list '
                      'can be Unix-style glob expressions.'),
-    cfg.StrOpt('emc_nas_server_container',
-               deprecated_for_removal=True,
-               deprecated_reason='Unity driver supports nas server auto load '
-                                 'balance.',
-               help='Storage processor to host the NAS server. Obsolete.'),
     cfg.StrOpt('unity_share_server',
                help='NAS server used for creating share when driver '
                     'is in DHSS=False mode. It is required when '
                     'driver_handles_share_servers=False in manila.conf.'),
+    cfg.StrOpt('report_default_filter_function',
+               default=False,
+               help='Whether or not report default filter function.'),
 ]
 
 CONF = cfg.CONF
@@ -96,6 +92,7 @@ class UnityStorageConnection(driver.StorageConnection):
         self.pool_set = None
         self.nas_server_pool = None
         self.reserved_percentage = None
+        self.reserved_snapshot_percentage = None
         self.max_over_subscription_ratio = None
         self.port_ids_conf = None
         self.unity_share_server = None
@@ -111,6 +108,10 @@ class UnityStorageConnection(driver.StorageConnection):
 
         # props from super class.
         self.driver_handles_share_servers = (True, False)
+        self.dhss_mandatory_security_service_association = {
+            'nfs': None,
+            'cifs': ['active_directory', ]
+        }
 
     def connect(self, emc_share_driver, context):
         """Connect to Unity storage."""
@@ -129,6 +130,11 @@ class UnityStorageConnection(driver.StorageConnection):
         if self.reserved_percentage is None:
             self.reserved_percentage = 0
 
+        self.reserved_snapshot_percentage = config.safe_get(
+            'reserved_share_from_snapshot_percentage')
+        if self.reserved_snapshot_percentage is None:
+            self.reserved_snapshot_percentage = self.reserved_percentage
+
         self.max_over_subscription_ratio = config.safe_get(
             'max_over_subscription_ratio')
         self.port_ids_conf = config.safe_get('unity_ethernet_ports')
@@ -144,6 +150,8 @@ class UnityStorageConnection(driver.StorageConnection):
         self.validate_port_configuration(self.port_ids_conf)
         pool_name = config.unity_server_meta_pool
         self._config_pool(pool_name)
+        self.report_default_filter_function = config.safe_get(
+            'report_default_filter_function')
 
     def get_server_name(self, share_server=None):
         if not self.driver_handles_share_servers:
@@ -583,6 +591,8 @@ class UnityStorageConnection(driver.StorageConnection):
                         enas_utils.bytes_to_gb(pool.size_subscribed),
                     'qos': False,
                     'reserved_percentage': self.reserved_percentage,
+                    'reserved_snapshot_percentage':
+                        self.reserved_snapshot_percentage,
                     'max_over_subscription_ratio':
                         self.max_over_subscription_ratio,
                 }
@@ -897,3 +907,8 @@ class UnityStorageConnection(driver.StorageConnection):
         """Reverts a share (in place) to the specified snapshot."""
         snapshot_id = unity_utils.get_snapshot_id(snapshot)
         return self.client.restore_snapshot(snapshot_id)
+
+    def get_default_filter_function(self):
+        if self.report_default_filter_function:
+            return "share.size >= 3"
+        return None
