@@ -32,6 +32,7 @@ import abc
 import math
 import os
 import re
+import shlex
 import socket
 
 from oslo_config import cfg
@@ -40,7 +41,6 @@ from oslo_utils import excutils
 from oslo_utils import importutils
 from oslo_utils import strutils
 from oslo_utils import units
-import six
 
 from manila.common import constants
 from manila import exception
@@ -55,7 +55,7 @@ LOG = log.getLogger(__name__)
 # matches multiple comma separated avpairs on a line.  values with an embedded
 # comma must be wrapped in quotation marks
 AVPATTERN = re.compile(r'\s*(?P<attr>\w+)\s*=\s*(?P<val>'
-                       '(["][a-zA-Z0-9_, ]+["])|(\w+))\s*[,]?')
+                       r'(["][a-zA-Z0-9_, ]+["])|(\w+))\s*[,]?')
 
 ERR_FILE_NOT_FOUND = 2
 
@@ -96,17 +96,6 @@ gpfs_share_opts = [
                     'CES=manila.share.drivers.ibm.gpfs.CESHelper',
                 ],
                 help='Specify list of share export helpers.'),
-    cfg.StrOpt('knfs_export_options',
-               default=('rw,sync,no_root_squash,insecure,no_wdelay,'
-                        'no_subtree_check'),
-               help=('Options to use when exporting a share using kernel '
-                     'NFS server. Note that these defaults can be overridden '
-                     'when a share is created by passing metadata with key '
-                     'name export_options.'),
-               deprecated_for_removal=True,
-               deprecated_reason="This option isn't used any longer. Please "
-                                 "use share-type extra specs for export "
-                                 "options."),
 ]
 
 
@@ -172,7 +161,7 @@ class GPFSShareDriver(driver.ExecuteMixin, driver.GaneshaMixin,
 
     def _sanitize_command(self, cmd_list):
         # pylint: disable=too-many-function-args
-        return ' '.join(six.moves.shlex_quote(cmd_arg) for cmd_arg in cmd_list)
+        return ' '.join(shlex.quote(cmd_arg) for cmd_arg in cmd_list)
 
     def _run_ssh(self, host, cmd_list, ignore_exit_code=None,
                  check_exit_code=True):
@@ -493,7 +482,7 @@ class GPFSShareDriver(driver.ExecuteMixin, driver.GaneshaMixin,
         return location
 
     def create_share_from_snapshot(self, ctx, share, snapshot,
-                                   share_server=None):
+                                   share_server=None, parent_share=None):
         """Is called to create share from a snapshot."""
         share_path = self._get_share_path(share)
         self._create_share_from_snapshot(share, snapshot, share_path)
@@ -758,7 +747,10 @@ class GPFSShareDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             share_backend_name=self.backend_name,
             vendor_name='IBM',
             storage_protocol='NFS',
-            reserved_percentage=self.configuration.reserved_share_percentage)
+            reserved_percentage=self.configuration.reserved_share_percentage,
+            reserved_snapshot_percentage=(
+                self.configuration.reserved_share_from_snapshot_percentage
+                or self.configuration.reserved_share_percentage))
 
         free, capacity = self._get_available_capacity(
             self.configuration.gpfs_mount_point_base)
@@ -790,8 +782,7 @@ class GPFSShareDriver(driver.ExecuteMixin, driver.GaneshaMixin,
                             snapshot["name"])
 
 
-@six.add_metaclass(abc.ABCMeta)
-class NASHelperBase(object):
+class NASHelperBase(metaclass=abc.ABCMeta):
     """Interface to work with share."""
 
     def __init__(self, execute, config_object):
@@ -884,7 +875,7 @@ class KNFSHelper(NASHelperBase):
             raise exception.GPFSException(msg)
 
         if access_to:
-            if (re.search(re.escape(local_path) + '[\s\n]*'
+            if (re.search(re.escape(local_path) + r'[\s\n]*'
                           + re.escape(access_to), out)):
                 return True
         else:
@@ -974,7 +965,7 @@ class KNFSHelper(NASHelperBase):
         if error_on_exists:
             # check if present in export
             out = re.search(
-                re.escape(local_path) + '[\s\n]*'
+                re.escape(local_path) + r'[\s\n]*'
                 + re.escape(access['access_to']), self._get_exports())
 
             if out is not None:
