@@ -1,4 +1,4 @@
-# Copyright 2022 Infinidat Ltd.
+# Copyright 2017 Infinidat Ltd.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -22,8 +22,6 @@ import ipaddress
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import units
-import requests
-import six
 
 from manila.common import constants
 from manila import exception
@@ -34,12 +32,9 @@ from manila import version
 
 try:
     import capacity
-except ImportError:
-    capacity = None
-
-try:
     import infinisdk
 except ImportError:
+    capacity = None
     infinisdk = None
 
 
@@ -48,14 +43,7 @@ LOG = logging.getLogger(__name__)
 infinidat_connection_opts = [
     cfg.HostAddressOpt('infinibox_hostname',
                        help='The name (or IP address) for the INFINIDAT '
-                       'Infinibox storage system.'),
-    cfg.BoolOpt('infinidat_use_ssl',
-                help='Use SSL to connect to the INFINIDAT Infinibox storage '
-                     'system.',
-                default=False),
-    cfg.BoolOpt('infinidat_suppress_ssl_warnings',
-                help='Suppress requests library SSL certificate warnings.',
-                default=False), ]
+                       'Infinibox storage system.'), ]
 
 infinidat_auth_opts = [
     cfg.StrOpt('infinibox_login',
@@ -73,22 +61,7 @@ infinidat_general_opts = [
                help='Name of the NAS network space on the INFINIDAT '
                'InfiniBox.'),
     cfg.BoolOpt('infinidat_thin_provision', help='Use thin provisioning.',
-                default=True),
-    cfg.BoolOpt('infinidat_snapdir_accessible',
-                help=('Controls access to the .snapshot directory. '
-                      'By default, each share allows access to its own '
-                      '.snapshot directory, which contains files and '
-                      'directories of each snapshot taken. To restrict '
-                      'access to the .snapshot directory, this option '
-                      'should be set to False.'),
-                default=True),
-    cfg.BoolOpt('infinidat_snapdir_visible',
-                help=('Controls visibility of the .snapshot directory. '
-                      'By default, each share contains the .snapshot '
-                      'directory, which is hidden on the client side. '
-                      'To make the .snapshot directory visible, this '
-                      'option should be set to True.'),
-                default=False), ]
+                default=True)]
 
 CONF = cfg.CONF
 CONF.register_opts(infinidat_connection_opts)
@@ -121,15 +94,8 @@ def infinisdk_to_manila_exceptions(func):
 
 
 class InfiniboxShareDriver(driver.ShareDriver):
-    """INFINIDAT InfiniBox Share driver.
 
-    Version history:
-        1.0 - initial release
-        1.1 - added support for TLS/SSL communication
-        1.2 - fixed host assisted migration
-    """
-
-    VERSION = '1.2'    # driver version
+    VERSION = '1.0'    # driver version
 
     def __init__(self, *args, **kwargs):
         super(InfiniboxShareDriver, self).__init__(False, *args, **kwargs)
@@ -137,9 +103,8 @@ class InfiniboxShareDriver(driver.ShareDriver):
         self.configuration.append_config_values(infinidat_auth_opts)
         self.configuration.append_config_values(infinidat_general_opts)
 
-    def _setup_and_get_system_object(self, management_address, auth, use_ssl):
-        system = infinisdk.InfiniBox(management_address, auth=auth,
-                                     use_ssl=use_ssl)
+    def _setup_and_get_system_object(self, management_address, auth):
+        system = infinisdk.InfiniBox(management_address, auth=auth)
         system.api.add_auto_retry(
             lambda e: isinstance(
                 e, infinisdk.core.exceptions.APITransportFailure) and
@@ -150,22 +115,11 @@ class InfiniboxShareDriver(driver.ShareDriver):
 
     def do_setup(self, context):
         """Driver initialization"""
-        if capacity is None:
-            msg = _("Missing 'capacity' python module, ensure the library"
-                    " is installed and available.")
-            raise exception.ManilaException(message=msg)
         if infinisdk is None:
             msg = _("Missing 'infinisdk' python module, ensure the library"
                     " is installed and available.")
             raise exception.ManilaException(message=msg)
 
-        if self.configuration.safe_get('infinidat_suppress_ssl_warnings'):
-            LOG.warning('Suppressing requests library SSL Warnings')
-            rpu = requests.packages.urllib3  # pylint: disable=no-member
-            rpu.disable_warnings(rpu.exceptions.InsecureRequestWarning)
-            rpu.disable_warnings(rpu.exceptions.InsecurePlatformWarning)
-
-        use_ssl = self.configuration.safe_get('infinidat_use_ssl')
         infinibox_login = self._safe_get_from_config_or_fail('infinibox_login')
         infinibox_password = (
             self._safe_get_from_config_or_fail('infinibox_password'))
@@ -181,8 +135,8 @@ class InfiniboxShareDriver(driver.ShareDriver):
             self._safe_get_from_config_or_fail(
                 'infinidat_nas_network_space_name'))
 
-        self._system = self._setup_and_get_system_object(management_address,
-                                                         auth, use_ssl)
+        self._system = (
+            self._setup_and_get_system_object(management_address, auth))
 
         backend_name = self.configuration.safe_get('share_backend_name')
         self._backend_name = backend_name or self.__class__.__name__
@@ -373,7 +327,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
         address, returns only that IP address.
         """
 
-        ip_address = six.text_type(ip_address)
+        ip_address = str(ip_address)
 
         # try treating the ip_address parameter as a range of IP addresses:
         ip_network = ipaddress.ip_network(ip_address, strict=False)
@@ -384,27 +338,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
 
     @infinisdk_to_manila_exceptions
     def _create_filesystem_export(self, infinidat_filesystem):
-        snapdir_visible = self.configuration.infinidat_snapdir_visible
-        infinidat_export = infinidat_filesystem.add_export(
-            permissions=[], snapdir_visible=snapdir_visible)
-        return self._make_export_locations(infinidat_export)
-
-    @infinisdk_to_manila_exceptions
-    def _ensure_filesystem_export(self, infinidat_filesystem):
-        try:
-            infinidat_export = self._get_export(infinidat_filesystem)
-        except exception.ShareBackendException:
-            return self._create_filesystem_export(infinidat_filesystem)
-        actual = infinidat_export.is_snapdir_visible()
-        expected = self.configuration.infinidat_snapdir_visible
-        if actual is not expected:
-            LOG.debug('Update snapdir_visible for %s: %s -> %s',
-                      infinidat_filesystem.get_name(), actual, expected)
-            infinidat_export.update_snapdir_visible(expected)
-        return self._make_export_locations(infinidat_export)
-
-    @infinisdk_to_manila_exceptions
-    def _make_export_locations(self, infinidat_export):
+        infinidat_export = infinidat_filesystem.add_export(permissions=[])
         export_paths = self._get_full_nfs_export_paths(
             infinidat_export.get_export_path())
         export_locations = [{
@@ -462,11 +396,10 @@ class InfiniboxShareDriver(driver.ShareDriver):
 
         pool = self._get_infinidat_pool()
         size = share['size'] * capacity.GiB    # pylint: disable=no-member
-        name = self._make_share_name(share)
-        snapdir_accessible = self.configuration.infinidat_snapdir_accessible
+        share_name = self._make_share_name(share)
+
         infinidat_filesystem = self._system.filesystems.create(
-            pool=pool, name=name, size=size, provtype=self._provtype,
-            snapdir_accessible=snapdir_accessible)
+            pool=pool, name=share_name, size=size, provtype=self._provtype)
         self._set_manila_object_metadata(infinidat_filesystem, share)
         return self._create_filesystem_export(infinidat_filesystem)
 
@@ -475,10 +408,8 @@ class InfiniboxShareDriver(driver.ShareDriver):
                                    share_server=None, parent_share=None):
         name = self._make_share_name(share)
         infinidat_snapshot = self._get_infinidat_snapshot(snapshot)
-        snapdir_accessible = self.configuration.infinidat_snapdir_accessible
         infinidat_new_share = infinidat_snapshot.create_snapshot(
-            name=name, write_protected=False,
-            snapdir_accessible=snapdir_accessible)
+            name=name, write_protected=False)
         self._extend_share(infinidat_new_share, share, share['size'])
         return self._create_filesystem_export(infinidat_new_share)
 
@@ -488,9 +419,7 @@ class InfiniboxShareDriver(driver.ShareDriver):
         share = snapshot['share']
         infinidat_filesystem = self._get_infinidat_filesystem(share)
         name = self._make_snapshot_name(snapshot)
-        snapdir_accessible = self.configuration.infinidat_snapdir_accessible
-        infinidat_snapshot = infinidat_filesystem.create_snapshot(
-            name=name, snapdir_accessible=snapdir_accessible)
+        infinidat_snapshot = infinidat_filesystem.create_snapshot(name=name)
         # snapshot is created in the same size as the original share, so no
         # extending is needed
         self._set_manila_object_metadata(infinidat_snapshot, snapshot)
@@ -513,32 +442,18 @@ class InfiniboxShareDriver(driver.ShareDriver):
         self._delete_share(snapshot, is_snapshot=True)
 
     def ensure_share(self, context, share, share_server=None):
-        """Ensure that share is properly configured and exported."""
         # will raise ShareResourceNotFound if the share was not found:
         infinidat_filesystem = self._get_infinidat_filesystem(share)
-        actual = infinidat_filesystem.is_snapdir_accessible()
-        expected = self.configuration.infinidat_snapdir_accessible
-        if actual is not expected:
-            LOG.debug('Update snapdir_accessible for %s: %s -> %s',
-                      infinidat_filesystem.get_name(), actual, expected)
-            infinidat_filesystem.update_field('snapdir_accessible', expected)
-        return self._ensure_filesystem_export(infinidat_filesystem)
-
-    def ensure_shares(self, context, shares):
-        """Invoked to ensure that shares are exported."""
-        updates = {}
-        for share in shares:
-            updates[share['id']] = {
-                'export_locations': self.ensure_share(context, share)}
-        return updates
-
-    def get_backend_info(self, context):
-        snapdir_accessible = self.configuration.infinidat_snapdir_accessible
-        snapdir_visible = self.configuration.infinidat_snapdir_visible
-        return {
-            'snapdir_accessible': snapdir_accessible,
-            'snapdir_visible': snapdir_visible
-        }
+        try:
+            infinidat_export = self._get_export(infinidat_filesystem)
+            return self._get_full_nfs_export_paths(
+                infinidat_export.get_export_path())
+        except exception.ShareBackendException:
+            # export not found, need to re-export
+            message = ("missing export for share %(share)s, trying to "
+                       "re-export")
+            LOG.info(message, {"share": share})
+            return self._create_filesystem_export(infinidat_filesystem)
 
     def update_access(self, context, share, access_rules, add_rules,
                       delete_rules, share_server=None):
