@@ -22,7 +22,6 @@ import functools
 import json
 import re
 import requests
-import six
 import time
 
 from oslo_config import cfg
@@ -142,13 +141,13 @@ class RestAPIExecutor(object):
             try:
                 return self.send_api(method, params, request_type)
             except exception.NetworkException as e:
-                msge = six.text_type(e)
+                msge = str(e)
                 LOG.error(msge)
 
                 self.refresh_token(force=True)
                 eventlet.sleep(1)
             except exception.ShareBackendException as e:
-                msge = six.text_type(e)
+                msge = str(e)
                 break
 
         msg = (_('Access RestAPI /rest/%(method)s by %(type)s failed,'
@@ -611,6 +610,9 @@ class AS13000ShareDriver(driver.ShareDriver):
             'pool_name': path,
             'reserved_percentage':
                 self.configuration.reserved_share_percentage,
+            'reserved_snapshot_percentage':
+                self.configuration.reserved_share_from_snapshot_percentage
+                or self.configuration.reserved_share_percentage,
             'max_over_subscription_ratio':
                 self.configuration.max_over_subscription_ratio,
             'dedupe': False,
