@@ -259,6 +259,9 @@ class QnapShareDriver(driver.ShareDriver):
         reserved_percentage = self.configuration.safe_get(
             'reserved_share_percentage')
 
+        reserved_snapshot_percentage = self.configuration.safe_get(
+            'reserved_share_from_snapshot_percentage') or reserved_percentage
+
         # single pool now, need support multiple pools in the future
         single_pool = {
             "pool_name": self.configuration.qnap_poolname,
@@ -266,6 +269,7 @@ class QnapShareDriver(driver.ShareDriver):
             "free_capacity_gb": free_capacity_gb,
             "allocated_capacity_gb": alloc_capacity_gb,
             "reserved_percentage": reserved_percentage,
+            "reserved_snapshot_percentage": reserved_snapshot_percentage,
             "qos": False,
             "dedupe": [True, False],
             "compression": [True, False],
@@ -286,7 +290,7 @@ class QnapShareDriver(driver.ShareDriver):
         }
         super(QnapShareDriver, self)._update_share_stats(data)
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=3,
                  retries=5)
     @utils.synchronized('qnap-create_share')
@@ -365,7 +369,7 @@ class QnapShareDriver(driver.ShareDriver):
                                        self.configuration.qnap_share_ip,
                                        volID)
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=5, retries=5, backoff_rate=1)
     def _get_share_info(self, share_name):
         share = self.api_executor.get_share_info(
@@ -441,7 +445,7 @@ class QnapShareDriver(driver.ShareDriver):
         }
         self.api_executor.edit_share(share_dict)
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=3,
                  retries=5)
     @utils.synchronized('qnap-create_snapshot')
@@ -514,7 +518,7 @@ class QnapShareDriver(driver.ShareDriver):
         self.api_executor.delete_snapshot_api(snapshot_id)
         self.private_storage.delete(snapshot['id'])
 
-    @utils.retry(exception=exception.ShareBackendException,
+    @utils.retry(retry_param=exception.ShareBackendException,
                  interval=3,
                  retries=5)
     @utils.synchronized('qnap-create_share_from_snapshot')
