@@ -25,7 +25,6 @@ import math
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import units
-import six
 
 from manila.common import constants
 from manila import exception
@@ -59,6 +58,10 @@ quobyte_manila_share_opts = [
     cfg.StrOpt('quobyte_default_volume_group',
                default='root',
                help='Default owning group for new volumes.'),
+    cfg.StrOpt('quobyte_export_path',
+               default='/quobyte',
+               help='Export path for shares of this bacckend. This needs '
+                    'to match the quobyte-nfs services "Pseudo" option.'),
 ]
 
 CONF = cfg.CONF
@@ -77,9 +80,12 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         1.2.2   - Minor optimizations
         1.2.3   - Updated RPC layer for improved stability
         1.2.4   - Fixed handling updated QB API error codes
+        1.2.5   - Fixed two quota handling bugs
+        1.2.6   - Fixed volume resize and jsonrpc code style bugs
+        1.2.7   - Add quobyte_export_path option
     """
 
-    DRIVER_VERSION = '1.2.4'
+    DRIVER_VERSION = '1.2.7'
 
     def __init__(self, *args, **kwargs):
         super(QuobyteShareDriver, self).__init__(False, *args, **kwargs)
@@ -88,9 +94,8 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                              or CONF.share_backend_name or 'Quobyte')
 
     def _fetch_existing_access(self, context, share):
-        volume_uuid = self._resolve_volume_name(
-            share['name'],
-            self._get_project_name(context, share['project_id']))
+        volume_uuid = self._resolve_volume_name(share['name'],
+                                                share['project_id'])
         result = self.rpc.call('getConfiguration', {})
         if result is None:
             raise exception.QBException(
@@ -136,7 +141,10 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             driver_version=self.DRIVER_VERSION,
             total_capacity_gb=total_gb,
             free_capacity_gb=free_gb,
-            reserved_percentage=self.configuration.reserved_share_percentage)
+            reserved_percentage=self.configuration.reserved_share_percentage,
+            reserved_snapshot_percentage=(
+                self.configuration.reserved_share_from_snapshot_percentage
+                or self.configuration.reserved_share_percentage))
         super(QuobyteShareDriver, self)._update_share_stats(data)
 
     def _get_capacities(self):
@@ -179,12 +187,15 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         return project_id
 
     def _resize_share(self, share, new_size):
+        newsize_bytes = new_size * units.Gi
         self.rpc.call('setQuota', {"quotas": [
             {"consumer":
                 [{"type": "VOLUME",
-                 "identifier": share["name"]}],
+                  "identifier": self._resolve_volume_name(share["name"],
+                                                          share['project_id']),
+                  "tenant_id": share["project_id"]}],
              "limits": [{"type": "LOGICAL_DISK_SPACE",
-                        "value": new_size}]}
+                        "value": newsize_bytes}]}
         ]})
 
     def _resolve_volume_name(self, volume_name, tenant_domain):
@@ -220,9 +231,8 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             raise exception.QBException(
                 _('Quobyte driver only supports NFS shares'))
 
-        volume_uuid = self._resolve_volume_name(
-            share['name'],
-            self._get_project_name(context, share['project_id']))
+        volume_uuid = self._resolve_volume_name(share['name'],
+                                                share['project_id'])
 
         if not volume_uuid:
             # create tenant, expect ERROR_GARBAGE_ARGS if it already exists
@@ -242,13 +252,14 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             volume_uuid=volume_uuid,
             protocol='NFS'))
 
-        return '%(nfs_server_ip)s:%(nfs_export_path)s' % result
+        self._resize_share(share, share['size'])
+
+        return self._build_share_export_string(result)
 
     def delete_share(self, context, share, share_server=None):
         """Delete the corresponding Quobyte volume."""
-        volume_uuid = self._resolve_volume_name(
-            share['name'],
-            self._get_project_name(context, share['project_id']))
+        volume_uuid = self._resolve_volume_name(share['name'],
+                                                share['project_id'])
         if not volume_uuid:
             LOG.warning("No volume found for "
                         "share %(project_id)s/%(name)s",
@@ -276,9 +287,8 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             the backend
         """
 
-        volume_uuid = self._resolve_volume_name(
-            share['name'],
-            self._get_project_name(context, share['project_id']))
+        volume_uuid = self._resolve_volume_name(share['name'],
+                                                share['project_id'])
 
         LOG.debug("Ensuring Quobyte share %s", share['name'])
 
@@ -290,7 +300,7 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             volume_uuid=volume_uuid,
             protocol='NFS'))
 
-        return '%(nfs_server_ip)s:%(nfs_export_path)s' % result
+        return self._build_share_export_string(result)
 
     def _allow_access(self, context, share, access, share_server=None):
         """Allow access to a share."""
@@ -298,9 +308,8 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             raise exception.InvalidShareAccess(
                 _('Quobyte driver only supports ip access control'))
 
-        volume_uuid = self._resolve_volume_name(
-            share['name'],
-            self._get_project_name(context, share['project_id']))
+        volume_uuid = self._resolve_volume_name(share['name'],
+                                                share['project_id'])
         ro = access['access_level'] == (constants.ACCESS_LEVEL_RO)
         call_params = {
             "volume_uuid": volume_uuid,
@@ -308,6 +317,12 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
             "add_allow_ip": access['access_to']}
         self.rpc.call('exportVolume', call_params)
 
+    def _build_share_export_string(self, rpc_result):
+        return '%(nfs_server_ip)s:%(qb_exp_path)s%(nfs_export_path)s' % {
+            "nfs_server_ip": rpc_result["nfs_server_ip"],
+            "qb_exp_path": self.configuration.quobyte_export_path,
+            "nfs_export_path": rpc_result["nfs_export_path"]}
+
     def _deny_access(self, context, share, access, share_server=None):
         """Remove white-list ip from a share."""
         if access['access_type'] != 'ip':
@@ -317,16 +332,15 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                       self._get_project_name(context, share['project_id']))
             return
 
-        volume_uuid = self._resolve_volume_name(
-            share['name'],
-            self._get_project_name(context, share['project_id']))
+        volume_uuid = self._resolve_volume_name(share['name'],
+                                                share['project_id'])
         call_params = {
             "volume_uuid": volume_uuid,
             "remove_allow_ip": access['access_to']}
         self.rpc.call('exportVolume', call_params)
 
     def extend_share(self, ext_share, ext_size, share_server=None):
-        """Uses resize_share to extend a share.
+        """Uses _resize_share to extend a share.
 
         :param ext_share: Share model.
         :param ext_size: New size of share (new_size > share['size']).
@@ -335,7 +349,7 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
         self._resize_share(share=ext_share, new_size=ext_size)
 
     def shrink_share(self, shrink_share, shrink_size, share_server=None):
-        """Uses resize_share to shrink a share.
+        """Uses _resize_share to shrink a share.
 
         Quobyte uses soft quotas. If a shares current size is bigger than
         the new shrunken size no data is lost. Data can be continuously read
@@ -389,12 +403,12 @@ class QuobyteShareDriver(driver.ExecuteMixin, driver.ShareDriver,):
                                                             existing_rules)
                 for a_rule in missing_rules:
                     LOG.debug("Adding rule %s in recovery.",
-                              six.text_type(a_rule))
+                              str(a_rule))
                     self._allow_access(context, share, a_rule)
 
                 superfluous_rules = self._subtract_access_lists(existing_rules,
                                                                 access_rules)
                 for d_rule in superfluous_rules:
                     LOG.debug("Removing rule %s in recovery.",
-                              six.text_type(d_rule))
+                              str(d_rule))
                     self._deny_access(context, share, d_rule)
