@@ -21,8 +21,8 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import excutils
 from oslo_utils import strutils
-import six
 
+from manila.api import common as api_common
 from manila.common import constants
 from manila.db import base
 from manila import exception
@@ -109,13 +109,19 @@ class API(base.Base):
                             "False, a share_network_id must not be provided.")
                     raise exception.InvalidInput(reason=msg)
 
+        share_network = {}
         try:
             if share_network_id:
-                self.db.share_network_get(context, share_network_id)
+                share_network = self.db.share_network_get(
+                    context, share_network_id)
         except exception.ShareNetworkNotFound:
             msg = _("The specified share network does not exist.")
             raise exception.InvalidInput(reason=msg)
 
+        if share_network:
+            # Check if share network is active, otherwise raise a BadRequest
+            api_common.check_share_network_is_active(share_network)
+
         if (driver_handles_share_servers and
                 not (source_share_group_snapshot_id or share_network_id)):
             msg = _("When using a share type with the "
@@ -327,7 +333,7 @@ class API(base.Base):
             search_opts = {}
 
         LOG.debug("Searching for share_groups by: %s",
-                  six.text_type(search_opts))
+                  search_opts)
 
         # Get filtered list of share_groups
         if search_opts.pop('all_tenants', 0) and context.is_admin:
@@ -482,7 +488,7 @@ class API(base.Base):
         if search_opts is None:
             search_opts = {}
         LOG.debug("Searching for share group snapshots by: %s",
-                  six.text_type(search_opts))
+                  search_opts)
 
         # Get filtered list of share group snapshots
         if search_opts.pop('all_tenants', 0) and context.is_admin:
@@ -501,5 +507,5 @@ class API(base.Base):
     def get_all_share_group_snapshot_members(self, context,
                                              share_group_snapshot_id):
         members = self.db.share_group_snapshot_members_get_all(
-            context,  share_group_snapshot_id)
+            context, share_group_snapshot_id)
         return members
