@@ -15,7 +15,6 @@
 #    under the License.
 
 import ddt
-import six
 
 from manila.api.openstack import api_version_request
 from manila.api.openstack import versioned_method
@@ -37,13 +36,15 @@ class APIVersionRequestTests(test.TestCase):
     def test_min_version(self):
 
         self.assertEqual(
-            api_version_request.APIVersionRequest(api_version_request._MIN_API_VERSION),
+            api_version_request.APIVersionRequest(
+                api_version_request._MIN_API_VERSION),
             api_version_request.min_api_version())
 
     def test_max_api_version(self):
 
         self.assertEqual(
-            api_version_request.APIVersionRequest(api_version_request._MAX_API_VERSION),
+            api_version_request.APIVersionRequest(
+                api_version_request._MAX_API_VERSION),
             api_version_request.max_api_version())
 
     @ddt.data(
@@ -184,13 +185,14 @@ class APIVersionRequestTests(test.TestCase):
         self.assertRaises(ValueError,
                           api_version_request.APIVersionRequest().get_string)
 
-    @ddt.data(('1', '0'), ('1', '1'))
+    @ddt.data(('1', '0', False), ('1', '1', False), ('1', '0', True))
     @ddt.unpack
-    def test_str(self, major, minor):
+    def test_str(self, major, minor, experimental):
         request_input = '%s.%s' % (major, minor)
-        request = api_version_request.APIVersionRequest(request_input)
-        request_string = six.text_type(request)
+        request = api_version_request.APIVersionRequest(
+            request_input, experimental=experimental)
+        request_string = str(request)
 
         self.assertEqual('API Version Request '
-                         'Major: %s, Minor: %s' % (major, minor),
-                         request_string)
\ No newline at end of file
+                         'Major: %s, Minor: %s, Experimental: %s' %
+                         (major, minor, experimental), request_string)
