@@ -33,7 +33,7 @@ def set_defaults(conf):
     _safe_set_of_opts(conf, 'connection', "sqlite://", group='database')
     _safe_set_of_opts(conf, 'sqlite_synchronous', False)
     _POLICY_PATH = os.path.abspath(os.path.join(CONF.state_path,
-                                                'manila/tests/policy.json'))
+                                                'manila/tests/policy.yaml'))
     opts.set_defaults(conf, policy_file=_POLICY_PATH)
     _safe_set_of_opts(conf, 'share_export_ip', '0.0.0.0')
     _safe_set_of_opts(conf, 'service_instance_user', 'fake_user')
@@ -41,6 +41,8 @@ def set_defaults(conf):
                                                    'etc/manila/api-paste.ini'))
     wsgi.register_opts(conf)
     _safe_set_of_opts(conf, 'api_paste_config', _API_PASTE_PATH)
+    # we use "fake" and "openstack" as project ID in a number of tests
+    _safe_set_of_opts(conf, 'project_id_regex', r"[0-9a-fopnstk\-]+")
     _safe_set_of_opts(conf, 'share_driver',
                       'manila.tests.fake_driver.FakeShareDriver')
     _safe_set_of_opts(conf, 'auth_strategy', 'noauth')
@@ -55,12 +57,28 @@ def set_defaults(conf):
     _safe_set_of_opts(conf, 'hitachi_hsp_username', 'hsp_user')
     _safe_set_of_opts(conf, 'hitachi_hsp_password', 'hsp_password')
 
+    _safe_set_of_opts(conf, 'as13000_nas_ip', '1.1.1.1')
+    _safe_set_of_opts(conf, 'as13000_nas_login', 'admin')
+    _safe_set_of_opts(conf, 'as13000_nas_password', 'password')
+    _safe_set_of_opts(conf, 'as13000_share_pools', 'pool0')
+
+    _safe_set_of_opts(conf, 'instorage_nas_ip', '1.1.1.1')
+    _safe_set_of_opts(conf, 'instorage_nas_login', 'admin')
+    _safe_set_of_opts(conf, 'instorage_nas_password', 'password')
+    _safe_set_of_opts(conf, 'instorage_nas_pools', 'pool0')
+
+    _safe_set_of_opts(conf, 'infortrend_nas_ip', '172.27.1.1')
+    _safe_set_of_opts(conf, 'infortrend_share_pools', 'share-pool-01')
+    _safe_set_of_opts(conf, 'infortrend_share_channels', '0,1')
+
     _safe_set_of_opts(conf, 'qnap_management_url', 'http://1.2.3.4:8080')
     _safe_set_of_opts(conf, 'qnap_share_ip', '1.2.3.4')
     _safe_set_of_opts(conf, 'qnap_nas_login', 'admin')
     _safe_set_of_opts(conf, 'qnap_nas_password', 'qnapadmin')
     _safe_set_of_opts(conf, 'qnap_poolname', 'Storage Pool 1')
 
+    _safe_set_of_opts(conf, 'unity_server_meta_pool', 'nas_server_pool')
+
 
 def _safe_set_of_opts(conf, *args, **kwargs):
     try:
