@@ -15,8 +15,10 @@
 """
 Tests For Data Manager
 """
+
+from unittest import mock
+
 import ddt
-import mock
 
 from manila.common import constants
 from manila import context
