@@ -61,7 +61,7 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         retval = sched._format_filter_properties(
             fake_context, {}, request_spec)
 
-        self.assertDictMatch(fake_type, retval[0]['resource_type'])
+        self.assertDictEqual(fake_type, retval[0]['resource_type'])
         self.assertIn('replication_domain', retval[0])
         # no "share_proto" was specified in the request_spec
         self.assertNotIn('storage_protocol', retval[0])
@@ -113,7 +113,7 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         retval = sched._format_filter_properties(
             fake_context, {}, request_spec)
 
-        self.assertDictMatch(fake_type, retval[0]['resource_type'])
+        self.assertDictEqual(fake_type, retval[0]['resource_type'])
         self.assertNotIn('share_backend_name',
                          retval[0]['share_type']['extra_specs'])
 
@@ -142,7 +142,7 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
         filter_spec = retval['share_type']['extra_specs']['storage_protocol']
         expected_spec = 'NFS_CIFS' if spec_present else '<in> CEPHFS'
         self.assertEqual(expected_spec, filter_spec)
-        self.assertDictMatch(fake_type, retval['resource_type'])
+        self.assertDictEqual(fake_type, retval['resource_type'])
 
     def test_create_share_no_hosts(self):
         # Ensure empty hosts/child_zones result in NoValidHosts exception.
@@ -152,7 +152,7 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_properties': {'project_id': 1, 'size': 1},
             'share_instance_properties': {},
             'share_type': {'name': 'NFS'},
-            'share_id': ['fake-id1'],
+            'share_id': 'fake-id1',
         }
         self.assertRaises(exception.NoValidHost, sched.schedule_create_share,
                           fake_context, request_spec, {})
@@ -177,7 +177,7 @@ class FilterSchedulerTestCase(test_base.SchedulerTestCase):
             'share_properties': {'project_id': 1, 'size': 1},
             'share_instance_properties': {},
             'share_type': {'name': 'NFS'},
-            'share_id': ['fake-id1'],
+            'share_id': 'fake-id1',
         }
         self.assertRaises(exception.NoValidHost, sched.schedule_create_share,
                           fake_context, request_spec, {})
