@@ -214,6 +214,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -244,6 +246,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@back2#CCC',
@@ -274,6 +278,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -326,6 +332,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@BBB#pool2',
@@ -357,6 +365,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host3@CCC#pool3',
@@ -388,6 +398,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4a',
@@ -419,6 +431,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host4@DDD#pool4b',
@@ -450,6 +464,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -514,6 +530,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 }, {
                     'name': 'host2@back1#BBB',
@@ -544,6 +562,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
@@ -602,6 +622,8 @@ class HostManagerTestCase(test.TestCase):
                         'replication_domain': None,
                         'sg_consistent_snapshot_support': None,
                         'security_service_update_support': False,
+                        'network_allocation_update_support': False,
+                        'share_server_multiple_subnet_support': False,
                     },
                 },
             ]
