@@ -221,37 +221,34 @@ class CephFSDriverTestCase(test.TestCase):
             share_server=None)
 
     def test_ensure_share(self):
-        expected_exports = {
-            'path': '1.2.3.4,5.6.7.8:/foo/bar',
-            'is_admin_only': False,
-            'metadata': {},
+        create_share_prefix = "fs subvolume create"
+        get_path_prefix = "fs subvolume getpath"
+
+        create_share_dict = {
+            "vol_name": self._driver.volname,
+            "sub_name": self._share["id"],
+            "size": self._share["size"] * units.Gi,
+            "namespace_isolated": True,
+            "mode": DEFAULT_VOLUME_MODE,
         }
-        self.mock_object(
-            self._driver, '_get_export_locations',
-            mock.Mock(return_value=expected_exports))
 
-        returned_exports = self._driver.ensure_share(self._context,
-                                                     self._share)
+        get_path_dict = {
+            "vol_name": self._driver.volname,
+            "sub_name": self._share["id"],
+        }
 
-        self._driver._get_export_locations.assert_called_once_with(self._share)
+        self._driver.ensure_share(self._context,
+                                  self._share)
 
-        self.assertEqual(expected_exports, returned_exports)
+        driver.rados_command.assert_has_calls([
+            mock.call(self._driver.rados_client,
+                      create_share_prefix,
+                      create_share_dict),
+            mock.call(self._driver.rados_client,
+                      get_path_prefix,
+                      get_path_dict)])
 
-    def test_ensure_share_subvolume_not_found(self):
-        message = f"Error ENOENT: subvolume {self._share['id']} does not exist"
-        expected_exception = exception.ShareBackendException(message)
-
-        self.mock_object(
-            self._driver, '_get_export_locations',
-            mock.Mock(side_effect=expected_exception))
-
-        self.assertRaises(
-            exception.ShareResourceNotFound,
-            self._driver.ensure_share,
-            self._context,
-            self._share)
-
-        self._driver._get_export_locations.assert_called_once_with(self._share)
+        self.assertEqual(2, driver.rados_command.call_count)
 
     def test_delete_share(self):
         clone_status_prefix = "fs clone status"
@@ -709,37 +706,6 @@ class NativeProtocolHelperTestCase(test.TestCase):
 
         self.assertEqual(2, driver.rados_command.call_count)
 
-    def test_deny_access_missing_access_rule(self):
-        access_deny_prefix = "fs subvolume deauthorize"
-
-        exception_msg = (
-            f"json_command failed - prefix=fs subvolume deauthorize, "
-            f"argdict='vol_name': {self._native_protocol_helper.volname}, "
-            f"'sub_name': '{self._share['id']}', 'auth_id': 'alice', "
-            f"'format': 'json' - exception message: [errno -2] "
-            f"auth ID: alice doesn't exist.")
-
-        driver.rados_command.side_effect = exception.ShareBackendException(
-            msg=exception_msg)
-
-        access_deny_dict = {
-            "vol_name": self._native_protocol_helper.volname,
-            "sub_name": self._share["id"],
-            "auth_id": "alice",
-        }
-
-        self._native_protocol_helper._deny_access(self._context, self._share, {
-            'access_level': 'rw',
-            'access_type': 'cephx',
-            'access_to': 'alice'
-        })
-
-        driver.rados_command.assert_called_once_with(
-            self._native_protocol_helper.rados_client,
-            access_deny_prefix, access_deny_dict)
-
-        self.assertEqual(1, driver.rados_command.call_count)
-
     def test_update_access_add_rm(self):
         alice = {
             'id': 'instance_mapping_id1',
@@ -1150,8 +1116,7 @@ class NFSProtocolHelperTestCase(test.TestCase):
         expected_ret = {
             "Name": "Ceph",
             "User_Id": "ganesha-fakeid",
-            "Secret_Access_Key": "ganesha-zorilla",
-            "Filesystem": self._nfs_helper.volname
+            "Secret_Access_Key": "ganesha-zorilla"
         }
 
         driver.rados_command.return_value = 'ganesha-zorilla'
