@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from oslo_utils import units
 
 from manila.common import constants as const
@@ -55,7 +56,7 @@ def response(func):
             'xml_api"><Response>'
             + func(*args, **kwargs)
             + '</Response></ResponsePacket>'
-        )
+        ).encode()
 
     return inner
 
@@ -1477,7 +1478,7 @@ class NFSShareTestData(StorageObjectTestData):
         if rw_hosts and ro_hosts:
             return (
                 '%(mover_name)s :\nexport "%(path)s" '
-                'access=-0.0.0.0/0.0.0.0:%(host)s root=%(host)s '
+                'access=%(host)s:-0.0.0.0/0.0.0.0 root=%(host)s '
                 'rw=%(rw_host)s ro=%(ro_host)s\n'
                 % {'mover_name': self.vdm_name,
                    'path': self.path,
@@ -1488,7 +1489,7 @@ class NFSShareTestData(StorageObjectTestData):
         elif rw_hosts:
             return (
                 '%(mover_name)s :\nexport "%(path)s" '
-                'access=-0.0.0.0/0.0.0.0:%(host)s root=%(host)s '
+                'access=%(host)s:-0.0.0.0/0.0.0.0 root=%(host)s '
                 'rw=%(rw_host)s\n'
                 % {'mover_name': self.vdm_name,
                    'host': ":".join(rw_hosts),
@@ -1498,7 +1499,7 @@ class NFSShareTestData(StorageObjectTestData):
         elif ro_hosts:
             return (
                 '%(mover_name)s :\nexport "%(path)s" '
-                'access=-0.0.0.0/0.0.0.0:%(host)s root=%(host)s '
+                'access=%(host)s:-0.0.0.0/0.0.0.0 root=%(host)s '
                 'ro=%(ro_host)s\n'
                 % {'mover_name': self.vdm_name,
                    'host': ":".join(ro_hosts),
@@ -1540,7 +1541,7 @@ class NFSShareTestData(StorageObjectTestData):
         ro_hosts = [utils.convert_ipv6_format_if_needed(ip_addr) for ip_addr in
                     ro_hosts]
 
-        access_str = ("access=-0.0.0.0/0.0.0.0:%(access_hosts)s,"
+        access_str = ("access=%(access_hosts)s:-0.0.0.0/0.0.0.0,"
                       "root=%(root_hosts)s,rw=%(rw_hosts)s,ro=%(ro_hosts)s" %
                       {'rw_hosts': ":".join(rw_hosts),
                        'ro_hosts': ":".join(ro_hosts),
@@ -1573,6 +1574,7 @@ class FakeEMCShareDriver(object):
         self.configuration.emc_nas_password = FakeData.emc_nas_password
         self.configuration.share_backend_name = FakeData.share_backend_name
 
+
 CIFS_SHARE = fake_share.fake_share(
     id=FakeData.share_id,
     name=FakeData.share_name,
