@@ -350,10 +350,12 @@ def do_connection_connect(conn, res):
     conn.pool_conf = ['pool_1', 'pool_2']
     conn.pool_set = set(['pool_1', 'pool_2'])
     conn.reserved_percentage = 0
+    conn.reserved_snapshot_percentage = 0
     conn.max_over_subscription_ratio = 20
     conn.port_set = set(['spa_eth1', 'spa_eth2'])
     conn.nas_server_pool = StorageObjectMock(res['nas_server_pool'])
     conn.storage_processor = StorageObjectMock(res['sp_a'])
+    conn.report_default_filter_function = False
 
 
 def patch_connection(func):
