@@ -15,8 +15,9 @@
 
 """Test cases for GlusterFS common routines."""
 
+from unittest import mock
+
 import ddt
-import mock
 from oslo_config import cfg
 
 from manila import exception
@@ -98,10 +99,20 @@ class GlusterManagerTestCase(test.TestCase):
         xmlout = mock.Mock()
         xmlout.find = mock.Mock(return_value=None)
 
-        ret = common.volxml_get(xmlout, 'some/path', default)
+        ret = common.volxml_get(xmlout, 'some/path', default=default)
 
         self.assertEqual(default, ret)
 
+    def test_volxml_get_multiple(self):
+        xmlout = mock.Mock()
+        value = mock.Mock()
+        value.text = 'foobar'
+        xmlout.find = mock.Mock(side_effect=(None, value))
+
+        ret = common.volxml_get(xmlout, 'some/path', 'better/path')
+
+        self.assertEqual('foobar', ret)
+
     def test_volxml_get_notfound(self):
         xmlout = mock.Mock()
         xmlout.find = mock.Mock(return_value=None)
@@ -385,11 +396,11 @@ class GlusterManagerTestCase(test.TestCase):
               {'opRet': '0', 'opErrno': '0', 'some/count': '2'})
     def test_xml_response_check_invalid(self, fdict):
 
-        def vxget(x, e, *a):
-            if a:
-                return fdict.get(e, a[0])
+        def vxget(x, *e, **kw):
+            if kw:
+                return fdict.get(e[0], kw['default'])
             else:
-                return fdict[e]
+                return fdict[e[0]]
 
         xtree = mock.Mock()
         command = ['volume', 'command', 'fake']
@@ -557,7 +568,8 @@ class GlusterManagerTestCase(test.TestCase):
         self._gluster_manager.gluster_call.assert_called_once_with(
             *args, check_exit_code=False)
 
-    def test_get_vol_regular_option(self):
+    @ddt.data({'start': "", 'end': ""}, {'start': "<Opt>", 'end': "</Opt>"})
+    def test_get_vol_regular_option(self, extratag):
 
         def xml_output(*ignore_args, **ignore_kwargs):
             return """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
@@ -567,10 +579,12 @@ class GlusterManagerTestCase(test.TestCase):
   <opErrstr/>
   <volGetopts>
     <count>1</count>
+    %(start)s
     <Option>nfs.export-dir</Option>
     <Value>/foo(10.0.0.1|10.0.0.2),/bar(10.0.0.1)</Value>
+    %(end)s
   </volGetopts>
-</cliOutput>""", ''
+</cliOutput>""" % extratag, ''
 
         args = ('--xml', 'volume', 'get', self._gluster_manager.volume,
                 NFS_EXPORT_DIR)
@@ -666,6 +680,7 @@ class GlusterManagerTestCase(test.TestCase):
             'volume', args[0], 'testvol', 'an_option', *args[1:],
             error_policy=mock.ANY)
 
+    @mock.patch('tenacity.nap.sleep', mock.Mock())
     @ddt.data({}, {'ignore_failure': False})
     def test_set_vol_option_error(self, kwargs):
         fake_obj = mock.Mock(
