@@ -15,9 +15,9 @@
 
 import errno
 import os
+from unittest import mock
 
 import ddt
-import mock
 from oslo_config import cfg
 from oslo_utils import importutils
 
@@ -264,7 +264,7 @@ class GlusterfsShareLayoutBaseTestCase(test.TestCase):
             """Is called to create share."""
 
         def create_share_from_snapshot(self, context, share, snapshot,
-                                       share_server=None):
+                                       share_server=None, parent_share=None):
             """Is called to create share from snapshot."""
 
         def create_snapshot(self, context, snapshot, share_server=None):
