@@ -15,7 +15,9 @@
 """Unit tests for INFINIDAT InfiniBox share driver."""
 
 import copy
-import mock
+import functools
+from unittest import mock
+
 from oslo_utils import units
 
 from manila.common import constants
@@ -23,6 +25,7 @@ from manila import exception
 from manila.share import configuration
 from manila.share.drivers.infinidat import infinibox
 from manila import test
+from manila import version
 
 
 _MOCK_SHARE_ID = 1
@@ -31,12 +34,16 @@ _MOCK_CLONE_ID = 3
 
 _MOCK_SHARE_SIZE = 4
 
+_MOCK_NETWORK_SPACE_IP_1 = '1.2.3.4'
+_MOCK_NETWORK_SPACE_IP_2 = '1.2.3.5'
+
 
 def _create_mock__getitem__(mock):
     def mock__getitem__(self, key, default=None):
         return getattr(mock, key, default)
     return mock__getitem__
 
+
 test_share = mock.Mock(id=_MOCK_SHARE_ID, size=_MOCK_SHARE_SIZE,
                        share_proto='NFS')
 test_share.__getitem__ = _create_mock__getitem__(test_share)
@@ -50,12 +57,16 @@ original_test_clone = mock.Mock(id=_MOCK_CLONE_ID, size=test_share.size,
 original_test_clone.__getitem__ = _create_mock__getitem__(original_test_clone)
 
 
+def skip_driver_setup(func):
+    @functools.wraps(func)
+    def f(*args, **kwargs):
+        return func(*args, **kwargs)
+    f.__skip_driver_setup = True
+    return f
+
+
 class FakeInfinisdkException(Exception):
-    def __init__(self, message=None, error_code=None, *args):
-        self.message = message
-        self.error_code = error_code
-        super(FakeInfinisdkException, self).__init__(
-            message, error_code, *args)
+    pass
 
 
 class FakeInfinisdkPermission(object):
@@ -70,6 +81,11 @@ class FakeInfinisdkPermission(object):
 
 
 class InfiniboxDriverTestCaseBase(test.TestCase):
+    def _test_skips_driver_setup(self):
+        test_method_name = self.id().split('.')[-1]
+        test_method = getattr(self, test_method_name)
+        return getattr(test_method, '__skip_driver_setup', False)
+
     def setUp(self):
         super(InfiniboxDriverTestCaseBase, self).setUp()
 
@@ -86,6 +102,7 @@ class InfiniboxDriverTestCaseBase(test.TestCase):
         self.configuration.admin_network_config_group = (
             'test_admin_network_config_group')
         self.configuration.reserved_share_percentage = 0
+        self.configuration.reserved_share_from_snapshot_percentage = 0
         self.configuration.filter_function = None
         self.configuration.goodness_function = None
         self.configuration.driver_handles_share_servers = False
@@ -108,7 +125,8 @@ class InfiniboxDriverTestCaseBase(test.TestCase):
         infinisdk.core.exceptions.InfiniSDKException = FakeInfinisdkException
         infinisdk.InfiniBox.return_value = self._system
 
-        self.driver.do_setup(None)
+        if not self._test_skips_driver_setup():
+            self.driver.do_setup(None)
 
     def _infinibox_mock(self):
         result = mock.Mock()
@@ -122,7 +140,8 @@ class InfiniboxDriverTestCaseBase(test.TestCase):
 
         self._mock_filesystem = mock.Mock()
         self._mock_filesystem.has_children.return_value = False
-        self._mock_filesystem.create_child.return_value = self._mock_filesystem
+        self._mock_filesystem.create_snapshot.return_value = (
+            self._mock_filesystem)
         self._mock_filesystem.get_exports.return_value = [self._mock_export, ]
 
         self._mock_filesystem.size = 4 * self._capacity_module.GiB
@@ -137,7 +156,8 @@ class InfiniboxDriverTestCaseBase(test.TestCase):
 
         self._mock_network_space = mock.Mock()
         self._mock_network_space.get_ips.return_value = (
-            [mock.Mock(ip_address='1.2.3.4'), mock.Mock(ip_address='1.2.3.5')])
+            [mock.Mock(ip_address=_MOCK_NETWORK_SPACE_IP_1, enabled=True),
+             mock.Mock(ip_address=_MOCK_NETWORK_SPACE_IP_2, enabled=True)])
 
         result.network_spaces.safe_get.return_value = self._mock_network_space
         result.pools.safe_get.return_value = self._mock_pool
@@ -168,6 +188,17 @@ class InfiniboxDriverTestCaseBase(test.TestCase):
 
 
 class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
+    def _generate_mock_metadata(self, share):
+        return {"system": "openstack",
+                "openstack_version": version.version_info.release_string(),
+                "manila_id": share['id'],
+                "manila_name": share['name'],
+                "host.created_by": infinibox._INFINIDAT_MANILA_IDENTIFIER}
+
+    def _validate_metadata(self, share):
+        self._mock_filesystem.set_metadata_from_dict.assert_called_once_with(
+            self._generate_mock_metadata(share))
+
     @mock.patch("manila.share.drivers.infinidat.infinibox.infinisdk", None)
     def test_no_infinisdk_module(self):
         self.assertRaises(exception.ManilaException,
@@ -185,6 +216,21 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
         self.assertRaises(exception.BadConfigurationException,
                           self.driver.do_setup, None)
 
+    @skip_driver_setup
+    def test__setup_and_get_system_object(self):
+        # This test should skip the driver setup, as it generates more calls to
+        # the add_auto_retry, set_source_identifier and login methods:
+        auth = (self.configuration.infinibox_login,
+                self.configuration.infinibox_password)
+
+        self.driver._setup_and_get_system_object(
+            self.configuration.infinibox_hostname, auth)
+
+        self._system.api.add_auto_retry.assert_called_once()
+        self._system.api.set_source_identifier.assert_called_once_with(
+            infinibox._INFINIDAT_MANILA_IDENTIFIER)
+        self._system.login.assert_called_once()
+
     def test_get_share_stats_refreshes(self):
         self.driver._update_share_stats()
         result = self.driver.get_share_stats()
@@ -259,10 +305,21 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
                           self.driver._get_infinidat_pool)
 
     def test__get_infinidat_nas_network_space_ips(self):
-        self.driver._get_infinidat_nas_network_space_ips()
+        network_space_ips = self.driver._get_infinidat_nas_network_space_ips()
         self._system.network_spaces.safe_get.assert_called_once()
         self._mock_network_space.get_ips.assert_called_once()
 
+        for network_space_ip in \
+                (_MOCK_NETWORK_SPACE_IP_1, _MOCK_NETWORK_SPACE_IP_2):
+            self.assertIn(network_space_ip, network_space_ips)
+
+    def test__get_infinidat_nas_network_space_ips_only_one_ip_enabled(self):
+        self._mock_network_space.get_ips.return_value = (
+            [mock.Mock(ip_address=_MOCK_NETWORK_SPACE_IP_1, enabled=True),
+             mock.Mock(ip_address=_MOCK_NETWORK_SPACE_IP_2, enabled=False)])
+        self.assertEqual([_MOCK_NETWORK_SPACE_IP_1],
+                         self.driver._get_infinidat_nas_network_space_ips())
+
     def test__get_infinidat_nas_network_space_ips_no_network_space(self):
         self._system.network_spaces.safe_get.return_value = None
         self.assertRaises(exception.ShareBackendException,
@@ -273,12 +330,30 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
         self.assertRaises(exception.ShareBackendException,
                           self.driver._get_infinidat_nas_network_space_ips)
 
+    def test__get_infinidat_nas_network_space_ips_no_ips_enabled(self):
+        self._mock_network_space.get_ips.return_value = (
+            [mock.Mock(ip_address=_MOCK_NETWORK_SPACE_IP_1, enabled=False),
+             mock.Mock(ip_address=_MOCK_NETWORK_SPACE_IP_2, enabled=False)])
+        self.assertRaises(exception.ShareBackendException,
+                          self.driver._get_infinidat_nas_network_space_ips)
+
     def test__get_infinidat_nas_network_space_api_error(self):
         self._system.network_spaces.safe_get.side_effect = (
             self._raise_infinisdk)
         self.assertRaises(exception.ShareBackendException,
                           self.driver._get_infinidat_nas_network_space_ips)
 
+    def test__get_full_nfs_export_paths(self):
+        export_paths = self.driver._get_full_nfs_export_paths(
+            self._mock_export.get_export_path())
+        for network_space_ip in \
+                (_MOCK_NETWORK_SPACE_IP_1, _MOCK_NETWORK_SPACE_IP_2):
+            self.assertIn(
+                "{network_space_ip}:{export_path}".format(
+                    network_space_ip=network_space_ip,
+                    export_path=self._mock_export.get_export_path()),
+                export_paths)
+
     def test__get_export(self):
         # The default return value of get_exports is [mock_export, ]:
         export = self.driver._get_export(self._mock_filesystem)
@@ -322,7 +397,7 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
         # This test uses the default infinidat_thin_provision = True setting:
         self.driver.create_share(None, test_share)
         self._system.filesystems.create.assert_called_once()
-        self._mock_filesystem.set_metadata_from_dict.assert_called_once()
+        self._validate_metadata(test_share)
         self._mock_filesystem.add_export.assert_called_once_with(
             permissions=[])
 
@@ -330,7 +405,7 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
         self.configuration.infinidat_thin_provision = False
         self.driver.create_share(None, test_share)
         self._system.filesystems.create.assert_called_once()
-        self._mock_filesystem.set_metadata_from_dict.assert_called_once()
+        self._validate_metadata(test_share)
         self._mock_filesystem.add_export.assert_called_once_with(
             permissions=[])
 
@@ -406,25 +481,25 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
 
     def test_create_snapshot(self):
         self.driver.create_snapshot(None, test_snapshot)
-        self._mock_filesystem.create_child.assert_called_once()
-        self._mock_filesystem.set_metadata_from_dict.assert_called_once()
+        self._mock_filesystem.create_snapshot.assert_called_once()
+        self._validate_metadata(test_snapshot)
         self._mock_filesystem.add_export.assert_called_once_with(
             permissions=[])
 
     def test_create_snapshot_metadata(self):
-        self._mock_filesystem.create_child.return_value = (
+        self._mock_filesystem.create_snapshot.return_value = (
             self._mock_filesystem)
         self.driver.create_snapshot(None, test_snapshot)
-        self._mock_filesystem.set_metadata_from_dict.assert_called_once()
+        self._validate_metadata(test_snapshot)
 
     def test_create_snapshot_share_doesnt_exist(self):
         self._system.filesystems.safe_get.return_value = None
         self.assertRaises(exception.ShareResourceNotFound,
                           self.driver.create_snapshot, None, test_snapshot)
 
-    def test_create_snapshot_create_child_api_fail(self):
+    def test_create_snapshot_create_snapshot_api_fail(self):
         # will fail when trying to create a child to the original share:
-        self._mock_filesystem.create_child.side_effect = (
+        self._mock_filesystem.create_snapshot.side_effect = (
             self._raise_infinisdk)
         self.assertRaises(exception.ShareBackendException,
                           self.driver.create_snapshot, None, test_snapshot)
@@ -439,7 +514,7 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
     def test_create_share_from_snapshot(self):
         self.driver.create_share_from_snapshot(None, original_test_clone,
                                                test_snapshot)
-        self._mock_filesystem.create_child.assert_called_once()
+        self._mock_filesystem.create_snapshot.assert_called_once()
         self._mock_filesystem.add_export.assert_called_once_with(
             permissions=[])
 
@@ -459,7 +534,7 @@ class InfiniboxDriverTestCase(InfiniboxDriverTestCaseBase):
                           None, original_test_clone, test_snapshot)
 
     def test_create_share_from_snapshot_create_fails(self):
-        self._mock_filesystem.create_child.side_effect = (
+        self._mock_filesystem.create_snapshot.side_effect = (
             self._raise_infinisdk)
         self.assertRaises(exception.ShareBackendException,
                           self.driver.create_share_from_snapshot,
