@@ -14,10 +14,10 @@
 
 """Unit tests for MapRFS native protocol driver module."""
 
-import mock
+from unittest import mock
+
 from oslo_concurrency import processutils
 from oslo_config import cfg
-import six
 
 from manila import context
 from manila import exception
@@ -247,7 +247,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
 
     def test__set_volume_size(self):
         volume = self._driver._volume_name(self.share['name'])
-        sizestr = six.text_type(self.share['size']) + 'G'
+        sizestr = str(self.share['size']) + 'G'
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
 
         self._driver._maprfs_util.set_volume_size(volume,
@@ -419,7 +419,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self.assertEqual(self.export_path, result[0]['path'])
 
     def test_create_share(self):
-        size_str = six.text_type(self.share['size']) + 'G'
+        size_str = str(self.share['size']) + 'G'
         path = self._driver._share_dir(self.share['name'])
         self._driver.api.get_share_metadata = mock.Mock(
             return_value={'_fake': 'fake'})
@@ -439,7 +439,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
                                                                        '777')
 
     def test_create_share_with_custom_name(self):
-        size_str = six.text_type(self.share['size']) + 'G'
+        size_str = str(self.share['size']) + 'G'
         self._driver.api.get_share_metadata = mock.Mock(
             return_value={'_name': 'fake', '_path': 'fake'})
         self._driver._maprfs_util._execute = mock.Mock(return_value=('', 0))
@@ -472,7 +472,7 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
     def test_create_share_from_snapshot(self):
         fake_snapshot = dict(self.snapshot)
         fake_snapshot.update(share_instance={'share_id': 1})
-        size_str = six.text_type(self.share['size']) + 'G'
+        size_str = str(self.share['size']) + 'G'
         path = self._driver._share_dir(self.share['name'])
         snapthot_path = self._driver._get_snapshot_path(self.snapshot) + '/*'
         self._driver._maprfs_util._execute = mock.Mock(
@@ -708,7 +708,8 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
             'qos', 'driver_version', 'share_backend_name',
             'free_capacity_gb', 'total_capacity_gb',
             'driver_handles_share_servers',
-            'reserved_percentage', 'vendor_name', 'storage_protocol',
+            'reserved_percentage', 'reserved_snapshot_percentage',
+            'vendor_name', 'storage_protocol',
         ]
         for key in expected_keys:
             self.assertIn(key, result)
@@ -798,7 +799,8 @@ class MapRFSNativeShareDriverTestCase(test.TestCase):
         self.mock_object(utils, 'SSHPool', mock.Mock(return_value=ssh_pool))
         self.mock_object(processutils, 'ssh_execute',
                          mock.Mock(return_value=ssh_output))
-        result = self._driver._maprfs_util._run_ssh(self.local_ip, cmd_list)
+        result = self._driver._maprfs_util._run_ssh(
+            self.local_ip, cmd_list, check_exit_code=False)
         utils.SSHPool.assert_called_once_with(
             self._driver.configuration.maprfs_clinode_ip[0],
             self._driver.configuration.maprfs_ssh_port,
