@@ -40,9 +40,16 @@ class NetAppClusteredCIFSHelperTestCase(test.TestCase):
         self.helper = cifs_cmode.NetAppCmodeCIFSHelper()
         self.helper.set_client(self.mock_client)
 
-    def test_create_share(self):
+    @ddt.data({'replica': True, 'cifs_exist': False},
+              {'replica': False, 'cifs_exist': True})
+    @ddt.unpack
+    def test_create_share(self, replica, cifs_exist):
 
-        result = self.helper.create_share(fake.CIFS_SHARE, fake.SHARE_NAME)
+        self.mock_client.cifs_share_exists.return_value = cifs_exist
+
+        result = self.helper.create_share(
+            fake.CIFS_SHARE, fake.SHARE_NAME,
+            replica=replica)
 
         export_addresses = [fake.SHARE_ADDRESS_1, fake.SHARE_ADDRESS_2]
         export_paths = [result(address) for address in export_addresses]
@@ -51,12 +58,32 @@ class NetAppClusteredCIFSHelperTestCase(test.TestCase):
             r'\\%s\%s' % (fake.SHARE_ADDRESS_2, fake.SHARE_NAME),
         ]
         self.assertEqual(expected_paths, export_paths)
-        self.mock_client.create_cifs_share.assert_called_once_with(
+
+        self.mock_client.cifs_share_exists.assert_called_once_with(
             fake.SHARE_NAME)
-        self.mock_client.remove_cifs_share_access.assert_called_once_with(
-            fake.SHARE_NAME, 'Everyone')
-        self.mock_client.set_volume_security_style.assert_called_once_with(
-            fake.SHARE_NAME, security_style='ntfs')
+        if cifs_exist:
+            self.mock_client.create_cifs_share.assert_not_called()
+            self.mock_client.remove_cifs_share.assert_not_called()
+        else:
+            self.mock_client.create_cifs_share.assert_called_once_with(
+                fake.SHARE_NAME)
+            self.mock_client.remove_cifs_share_access.assert_called_once_with(
+                fake.SHARE_NAME, 'Everyone')
+
+        if replica:
+            self.mock_client.set_volume_security_style.assert_not_called()
+        else:
+            self.mock_client.set_volume_security_style.assert_called_once_with(
+                fake.SHARE_NAME, security_style='ntfs')
+
+    def test_create_share_ensure_not_exist_error(self):
+
+        self.mock_client.cifs_share_exists.return_value = False
+
+        self.assertRaises(exception.NetAppException,
+                          self.helper.create_share,
+                          fake.CIFS_SHARE, fake.SHARE_NAME,
+                          ensure_share_already_exists=True)
 
     def test_delete_share(self):
 
@@ -209,11 +236,14 @@ class NetAppClusteredCIFSHelperTestCase(test.TestCase):
 
         share = fake.CIFS_SHARE.copy()
         share['export_location'] = location
+        self.mock_object(self.helper, '_get_share_export_location',
+                         mock.Mock(return_value=location))
 
         result_ip, result_share_name = self.helper._get_export_location(share)
 
         self.assertEqual(ip, result_ip)
         self.assertEqual(share_name, result_share_name)
+        self.helper._get_share_export_location.assert_called_once_with(share)
 
     def test_cleanup_demoted_replica(self):
         self.helper.cleanup_demoted_replica(fake.CIFS_SHARE, fake.SHARE_NAME)
