@@ -25,6 +25,10 @@ from oslo_utils import timeutils
 from manila.common import constants as const
 from manila import context
 from manila import exception
+from manila.privsep import common as privsep_common
+from manila.privsep import filesystem
+from manila.privsep import lvm as privsep_lvm
+from manila.privsep import os as os_routines
 from manila.share import configuration
 from manila.share.drivers import lvm
 from manila import test
@@ -134,29 +138,28 @@ class LVMShareDriverTestCase(test.TestCase):
         ])
 
     def test_check_for_setup_error(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            return '\n   fake1\n   fakevg\n   fake2\n', ''
+        out, err = '\n   fake1\n   fakevg\n   fake2\n', ''
+        self.mock_object(privsep_lvm, 'list_vgs_get_name',
+                         mock.Mock(return_value=(out, err)))
 
-        expected_exec = ['vgs --noheadings -o name']
-        fake_utils.fake_execute_set_repliers([(expected_exec[0], exec_runner)])
         self._driver.check_for_setup_error()
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+
+        privsep_lvm.list_vgs_get_name.assert_called_once()
 
     def test_check_for_setup_error_no_vg(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            return '\n   fake0\n   fake1\n   fake2\n', ''
-
-        fake_utils.fake_execute_set_repliers([('vgs --noheadings -o name',
-                                               exec_runner)])
+        out = '\n   fake0\n   fake1\n   fake2\n'
+        err = ''
+        self.mock_object(privsep_lvm, 'list_vgs_get_name',
+                         mock.Mock(return_value=(out, err)))
         self.assertRaises(exception.InvalidParameterValue,
                           self._driver.check_for_setup_error)
 
     def test_check_for_setup_error_no_export_ips(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            return '\n   fake1\n   fakevg\n   fake2\n', ''
+        out = '\n   fake1\n   fakevg\n   fake2\n'
+        err = ''
+        self.mock_object(privsep_lvm, 'list_vgs_get_name',
+                         mock.Mock(return_value=(out, err)))
 
-        fake_utils.fake_execute_set_repliers([('vgs --noheadings -o name',
-                                               exec_runner)])
         CONF.set_default('lvm_share_export_ips', None)
         self.assertRaises(exception.InvalidParameterValue,
                           self._driver.check_for_setup_error)
@@ -176,17 +179,22 @@ class LVMShareDriverTestCase(test.TestCase):
     def test_create_share(self):
         CONF.set_default('lvm_share_mirrors', 0)
         self._driver._mount_device = mock.Mock()
+        lv_create_mock = privsep_lvm.lvcreate = mock.Mock()
+        lv_create_args = [
+            self.share['size'], self.share['name'],
+            CONF.lvm_share_volume_group, 0, 0]
+        self.mock_object(privsep_common, 'execute_with_retries')
+        self.mock_object(filesystem, 'make_filesystem')
 
         ret = self._driver.create_share(self._context, self.share,
                                         self.share_server)
 
         self._driver._mount_device.assert_called_with(
             self.share, '/dev/mapper/fakevg-fakename')
-        expected_exec = [
-            'lvcreate -Wy --yes -L 1G -n fakename fakevg',
-            'mkfs.ext4 /dev/mapper/fakevg-fakename',
-        ]
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+        privsep_common.execute_with_retries.assert_called_once_with(
+            lv_create_mock, lv_create_args, CONF.num_shell_tries)
+        filesystem.make_filesystem.assert_called_once_with(
+            'ext4', '/dev/mapper/fakevg-fakename')
         self.assertEqual(self._helper_nfs.create_exports.return_value, ret)
 
     def test_create_share_from_snapshot(self):
@@ -199,6 +207,21 @@ class LVMShareDriverTestCase(test.TestCase):
         mount_share = '/dev/mapper/fakevg-fakename'
         mount_snapshot = '/dev/mapper/fakevg-fakename'
         self._helper_nfs.create_export.return_value = 'fakelocation'
+        lv_create_mock = privsep_lvm.lvcreate = mock.Mock()
+        lv_create_args = [
+            self.share['size'], self.share['name'],
+            CONF.lvm_share_volume_group, 0, 0]
+
+        self.mock_object(privsep_common, 'execute_with_retries')
+        self.mock_object(os_routines, 'is_data_definition_direct_io_supported',
+                         mock.Mock(return_value=True))
+        self.mock_object(os_routines, 'data_definition')
+        self.mock_object(os_routines, 'mount')
+        self.mock_object(os_routines, 'chmod')
+        self.mock_object(filesystem, 'make_filesystem')
+        self.mock_object(filesystem, 'e2fsck')
+        self.mock_object(filesystem, 'tune2fs')
+
         self._driver.create_share_from_snapshot(self._context,
                                                 self.share,
                                                 snapshot_instance,
@@ -206,44 +229,59 @@ class LVMShareDriverTestCase(test.TestCase):
 
         self._driver._mount_device.assert_called_with(self.share,
                                                       mount_snapshot)
-        expected_exec = [
-            'lvcreate -Wy --yes -L 1G -n fakename fakevg',
-            'mkfs.ext4 /dev/mapper/fakevg-fakename',
-            'e2fsck -y -f %s' % mount_share,
-            'tune2fs -U random %s' % mount_share,
-            ("dd count=0 if=%s of=%s iflag=direct oflag=direct" %
-             (mount_snapshot, mount_share)),
-            ("dd if=%s of=%s count=1024 bs=1M iflag=direct oflag=direct" %
-             (mount_snapshot, mount_share)),
-        ]
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+        privsep_common.execute_with_retries.assert_called_once_with(
+            lv_create_mock, lv_create_args, 3)
+        filesystem.make_filesystem.assert_called_once_with(
+            'ext4', '/dev/mapper/fakevg-fakename')
+        filesystem.e2fsck.assert_called_once_with(
+            mount_share)
+        filesystem.tune2fs.assert_called_once_with(
+            mount_share)
+        (os_routines.is_data_definition_direct_io_supported
+            .assert_called_once_with(
+                mount_snapshot, mount_share))
+        os_routines.data_definition.assert_called_once_with(
+            mount_snapshot, mount_share, (self.share['size'] * 1024),
+            use_direct_io=True)
 
     def test_create_share_mirrors(self):
         share = fake_share(size='2048')
         CONF.set_default('lvm_share_mirrors', 2)
+        lv_create_mock = privsep_lvm.lvcreate = mock.Mock()
+        lv_create_args = [
+            '2048', self.share['name'],
+            CONF.lvm_share_volume_group, 2, '2']
+
         self._driver._mount_device = mock.Mock()
+        self.mock_object(privsep_common, 'execute_with_retries')
+        self.mock_object(filesystem, 'make_filesystem')
 
         ret = self._driver.create_share(self._context, share,
                                         self.share_server)
 
         self._driver._mount_device.assert_called_with(
             share, '/dev/mapper/fakevg-fakename')
-        expected_exec = [
-            'lvcreate -Wy --yes -L 2048G -n fakename fakevg -m 2 --nosync'
-            ' -R 2', 'mkfs.ext4 /dev/mapper/fakevg-fakename']
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+        privsep_common.execute_with_retries.assert_called_once_with(
+            lv_create_mock, lv_create_args, 3)
+        filesystem.make_filesystem.assert_called_once_with(
+            'ext4', '/dev/mapper/fakevg-fakename')
         self.assertEqual(self._helper_nfs.create_exports.return_value, ret)
 
     def test_deallocate_container(self):
-        expected_exec = ['lvremove -f fakevg/fakename']
+        mock_lvremove = privsep_lvm.lvremove = mock.Mock()
+        self.mock_object(privsep_common, 'execute_with_retries')
+
         self._driver._deallocate_container(self.share['name'])
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+
+        privsep_common.execute_with_retries.assert_called_once_with(
+            mock_lvremove, [CONF.lvm_share_volume_group, self.share['name']], 3
+        )
 
     def test_deallocate_container_error(self):
         def _fake_exec(*args, **kwargs):
             raise exception.ProcessExecutionError(stderr="error")
 
-        self.mock_object(self._driver, '_try_execute', _fake_exec)
+        self.mock_object(privsep_common, 'execute_with_retries', _fake_exec)
         self.assertRaises(exception.ProcessExecutionError,
                           self._driver._deallocate_container,
                           self.share['name'])
@@ -255,7 +293,7 @@ class LVMShareDriverTestCase(test.TestCase):
         def _fake_exec(*args, **kwargs):
             raise exception.ProcessExecutionError(stderr=error_msg)
 
-        self.mock_object(self._driver, '_try_execute', _fake_exec)
+        self.mock_object(privsep_common, 'execute_with_retries', _fake_exec)
         self._driver._deallocate_container(self.share['name'])
 
     @mock.patch.object(lvm.LVMShareDriver, '_update_share_stats', mock.Mock())
@@ -272,74 +310,94 @@ class LVMShareDriverTestCase(test.TestCase):
         self._driver._update_share_stats.assert_called_once_with()
 
     def test__unmount_device_not_mounted(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            umount_msg = (
-                "umount: /opt/stack/data/manila/mnt/share-fake-share: not "
-                "mounted.\n"
-            )
-            raise exception.ProcessExecutionError(stderr=umount_msg)
-        self._os.path.exists.return_value = True
         mount_path = self._get_mount_path(self.share)
-        expected_exec = "umount -f %s" % (mount_path)
-        fake_utils.fake_execute_set_repliers([(expected_exec, exec_runner)])
+        error_msg = (
+            "umount: /opt/stack/data/manila/mnt/share-fake-share: not "
+            "mounted.\n")
+        umount_exception = exception.ProcessExecutionError(stderr=error_msg)
+        self.mock_object(
+            os_routines, 'umount', mock.Mock(side_effect=umount_exception))
+        self.mock_object(os_routines, 'rmdir')
+        self._os.path.exists.return_value = True
 
         self._driver._unmount_device(self.share, raise_if_missing=False)
 
         self._os.path.exists.assert_called_with(mount_path)
+        os_routines.umount.assert_called_once_with(mount_path)
 
     def test__unmount_device_is_busy_error(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            raise exception.ProcessExecutionError(stderr='device is busy')
+        error_msg = 'device is busy'
+        umount_exception = exception.ProcessExecutionError(stderr=error_msg)
+        self.mock_object(
+            os_routines, 'umount', mock.Mock(side_effect=umount_exception))
         self._os.path.exists.return_value = True
         mount_path = self._get_mount_path(self.share)
-        expected_exec = [
-            "umount -f %s" % (mount_path),
-        ]
-        fake_utils.fake_execute_set_repliers([(expected_exec[0], exec_runner)])
 
         self.assertRaises(exception.ShareBusyException,
                           self._driver._unmount_device,
                           self.share)
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+        os_routines.umount.assert_called_once_with(mount_path)
 
     def test__unmount_device_error(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            raise exception.ProcessExecutionError(stderr='fake error')
+        error_msg = 'fake error'
         mount_path = self._get_mount_path(self.share)
+        umount_exception = exception.ProcessExecutionError(stderr=error_msg)
+        self.mock_object(
+            os_routines, 'umount', mock.Mock(side_effect=umount_exception))
         self._os.path.exists.return_value = True
-        cmd = "umount -f %s" % (mount_path)
-        fake_utils.fake_execute_set_repliers([(cmd, exec_runner)])
+
         self.assertRaises(processutils.ProcessExecutionError,
                           self._driver._unmount_device,
                           self.share)
         self._os.path.exists.assert_called_with(mount_path)
+        os_routines.umount.assert_called_once_with(mount_path)
 
     def test__unmount_device_rmdir_error(self):
-        def exec_runner(*ignore_args, **ignore_kwargs):
-            raise exception.ProcessExecutionError(stderr='fake error')
+        error_msg = 'fake error'
         mount_path = self._get_mount_path(self.share)
+        umount_exception = exception.ProcessExecutionError(stderr=error_msg)
+        self.mock_object(os_routines, 'umount')
+        self.mock_object(os_routines, 'rmdir',
+                         mock.Mock(side_effect=umount_exception))
         self._os.path.exists.return_value = True
-        cmd = "rmdir %s" % (mount_path)
-        fake_utils.fake_execute_set_repliers([(cmd, exec_runner)])
-        self.assertRaises(processutils.ProcessExecutionError,
+
+        self.assertRaises(exception.ShareBackendException,
                           self._driver._unmount_device,
                           self.share)
         self._os.path.exists.assert_called_with(mount_path)
+        os_routines.umount.assert_called_once_with(mount_path)
+        os_routines.rmdir.assert_called_once_with(mount_path)
 
     def test_create_snapshot(self):
+        mock_lv_create = privsep_lvm.lvcreate = mock.Mock()
+        orig_lv_name = "%s/%s" % (CONF.lvm_share_volume_group,
+                                  self.snapshot['share_name'])
+        device_path = '/dev/mapper/fakevg-%s' % self.snapshot['name']
+        lv_create_args = [
+            self.snapshot['share']['size'], self.snapshot['share']['name'],
+            orig_lv_name]
+
+        self.mock_object(privsep_common, 'execute_with_retries')
+        self.mock_object(filesystem, 'e2fsck')
+        self.mock_object(filesystem, 'tune2fs')
+        self.mock_object(os_routines, 'mount')
+        self.mock_object(os_routines, 'chmod')
+
         self._driver.create_snapshot(self._context, self.snapshot,
                                      self.share_server)
         mount_path = self._get_mount_path(self.snapshot)
         expected_exec = [
-            ("lvcreate -L 1G --name fakesnapshotname --snapshot "
-             "%s/fakename" % (CONF.lvm_share_volume_group,)),
-            "e2fsck -y -f /dev/mapper/fakevg-%s" % self.snapshot['name'],
-            "tune2fs -U random /dev/mapper/fakevg-%s" % self.snapshot['name'],
             "mkdir -p " + mount_path,
-            "mount /dev/mapper/fakevg-fakesnapshotname " + mount_path,
-            "chmod 777 " + mount_path,
         ]
         self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+        privsep_common.execute_with_retries(
+            mock_lv_create, lv_create_args, CONF.num_shell_tries)
+        filesystem.e2fsck.assert_called_once_with(device_path)
+        filesystem.tune2fs.assert_called_once_with(device_path)
+        os_routines.mount.assert_called_once_with(
+            "/dev/mapper/fakevg-fakesnapshotname", mount_path)
+        os_routines.chmod.assert_called_once_with(
+            '777', mount_path)
 
     def test_ensure_share(self):
         device_name = '/dev/mapper/fakevg-fakename'
@@ -360,20 +418,32 @@ class LVMShareDriverTestCase(test.TestCase):
 
     def test_delete_snapshot(self):
         mount_path = self._get_mount_path(self.snapshot)
-        expected_exec = [
-            'umount -f %s' % mount_path,
-            'rmdir %s' % mount_path,
-            'lvremove -f fakevg/fakesnapshotname',
-        ]
+        self.mock_object(os_routines, 'umount')
+        self.mock_object(os_routines, 'rmdir')
+        self.mock_object(privsep_common, 'execute_with_retries')
+        self.mock_object(self._driver, '_deallocate_container')
+
         self._driver.delete_snapshot(self._context, self.snapshot,
                                      self.share_server)
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+
+        os_routines.umount.assert_called_once_with(mount_path)
+        os_routines.rmdir.assert_called_once_with(mount_path)
+        self._driver._deallocate_container.assert_called_once_with(
+            self.snapshot['name'])
 
     def test_delete_share_invalid_share(self):
+        self.mock_object(self._driver, '_unmount_device')
+        self.mock_object(self._driver, '_deallocate_container')
         self._driver._get_helper = mock.Mock(
             side_effect=exception.InvalidShare(reason='fake'))
+
         self._driver.delete_share(self._context, self.share, self.share_server)
 
+        self._driver._unmount_device.assert_called_once_with(
+            self.share, raise_if_missing=False, retry_busy_device=True)
+        self._driver._deallocate_container.assert_called_once_with(
+            self.share['name'])
+
     def test_delete_share_process_execution_error(self):
         self.mock_object(
             self._helper_nfs,
@@ -421,13 +491,18 @@ class LVMShareDriverTestCase(test.TestCase):
 
     def test_mount_device(self):
         mount_path = self._get_mount_path(self.share)
-        ret = self._driver._mount_device(self.share, 'fakedevice')
+        self.mock_object(os_routines, 'mount')
+        self.mock_object(os_routines, 'chmod')
         expected_exec = [
             "mkdir -p %s" % (mount_path,),
-            "mount fakedevice %s" % (mount_path,),
-            "chmod 777 %s" % (mount_path,),
         ]
+        device_name = 'fakedevice'
+
+        ret = self._driver._mount_device(self.share, device_name)
+
         self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
+        os_routines.mount.assert_called_once_with(device_name, mount_path)
+        os_routines.chmod.assert_called_once_with('777', mount_path)
         self.assertEqual(mount_path, ret)
 
     def test_mount_device_already(self):
@@ -438,19 +513,22 @@ class LVMShareDriverTestCase(test.TestCase):
                 return 'fakedevice', ''
 
         self.mock_object(self._driver, '_execute', exec_runner)
+        self.mock_object(os_routines, 'mount')
+        self.mock_object(os_routines, 'chmod')
         mount_path = self._get_mount_path(self.share)
 
         ret = self._driver._mount_device(self.share, 'fakedevice')
         self.assertEqual(mount_path, ret)
 
     def test_mount_device_error(self):
-        def exec_runner(*args, **kwargs):
-            if 'mount' in args and '-l' not in args:
-                raise exception.ProcessExecutionError()
-            else:
-                return 'fake', ''
+        self.mock_object(self._driver, '_execute')
+        self.mock_object(
+            os_routines, 'mount',
+            mock.Mock(side_effect=exception.ProcessExecutionError))
+        self.mock_object(
+            os_routines, 'list_mounts',
+            mock.Mock(return_value=('fake', '')))
 
-        self.mock_object(self._driver, '_execute', exec_runner)
         self.assertRaises(exception.ProcessExecutionError,
                           self._driver._mount_device, self.share, 'fakedevice')
 
@@ -477,8 +555,9 @@ class LVMShareDriverTestCase(test.TestCase):
         ] if retry_busy_device else [None, None]
         mount_path = self._get_mount_path(self.share)
         self._os.path.exists.return_value = True
-        self.mock_object(self._driver, '_execute', mock.Mock(
+        self.mock_object(os_routines, 'umount', mock.Mock(
             side_effect=execute_sideeffects))
+        self.mock_object(os_routines, 'rmdir')
 
         self._driver._unmount_device(self.share,
                                      retry_busy_device=retry_busy_device)
@@ -486,11 +565,9 @@ class LVMShareDriverTestCase(test.TestCase):
         num_of_times_umount_is_called = 3 if retry_busy_device else 1
 
         self._os.path.exists.assert_called_with(mount_path)
-        self._driver._execute.assert_has_calls([
-            mock.call('umount', '-f', mount_path, run_as_root=True),
-        ] * num_of_times_umount_is_called + [
-            mock.call('rmdir', mount_path, run_as_root=True)
-        ])
+        os_routines.umount.assert_has_calls([
+            mock.call(mount_path)] * num_of_times_umount_is_called)
+        os_routines.rmdir.assert_called_once_with(mount_path)
 
     def test_extend_share(self):
         local_path = self._driver._get_local_path(self.share)
@@ -515,15 +592,13 @@ class LVMShareDriverTestCase(test.TestCase):
             'fake_command', run_as_root=True, check_exit_code=True)
 
     def test_extend_container(self):
-        self.mock_object(self._driver, '_try_execute')
+        mock_lvextend = privsep_lvm.lvextend = mock.Mock()
+
+        self.mock_object(privsep_common, 'execute_with_retries')
         self._driver._extend_container(self.share, 'device_name', 3)
-        self._driver._try_execute.assert_called_once_with(
-            'lvextend',
-            '-L',
-            '3G',
-            '-r',
-            'device_name',
-            run_as_root=True)
+
+        privsep_common.execute_with_retries.assert_called_once_with(
+            mock_lvextend, ['device_name', 3], CONF.num_shell_tries)
 
     def test_get_share_server_pools(self):
         expected_result = [{
@@ -533,30 +608,32 @@ class LVMShareDriverTestCase(test.TestCase):
             'reserved_percentage': 0,
             'reserved_snapshot_percentage': 0,
         }, ]
+        out, err = "VSize 33g VFree 22g", None
         self.mock_object(
-            self._driver,
-            '_execute',
-            mock.Mock(return_value=("VSize 33g VFree 22g", None)))
+            privsep_lvm, 'get_vgs', mock.Mock(return_value=(out, err)))
 
         self.assertEqual(expected_result,
                          self._driver.get_share_server_pools())
-        self._driver._execute.assert_called_once_with(
-            'vgs', 'fakevg', '--rows', '--units', 'g', run_as_root=True)
 
-    def test_copy_volume_error(self):
-        def _fake_exec(*args, **kwargs):
-            if 'count=0' in args:
-                raise exception.ProcessExecutionError()
+    @ddt.data(True, False)
+    def test_copy_volume_error(self, use_direct_io):
+        src_str = 'src'
+        dest_str = 'dest'
+        self.mock_object(
+            os_routines, 'is_data_definition_direct_io_supported',
+            mock.Mock(return_value=use_direct_io))
+        self.mock_object(
+            os_routines, 'data_definition',
+            mock.Mock(side_effect=exception.ProcessExecutionError))
 
-        self.mock_object(self._driver, '_execute',
-                         mock.Mock(side_effect=_fake_exec))
-        self._driver._copy_volume('src', 'dest', 1)
-        self._driver._execute.assert_any_call('dd', 'count=0', 'if=src',
-                                              'of=dest', 'iflag=direct',
-                                              'oflag=direct', run_as_root=True)
-        self._driver._execute.assert_any_call('dd', 'if=src', 'of=dest',
-                                              'count=1024', 'bs=1M',
-                                              run_as_root=True)
+        self.assertRaises(
+            exception.ShareBackendException,
+            self._driver._copy_volume, src_str, dest_str, 1)
+        (os_routines.is_data_definition_direct_io_supported
+            .assert_called_once_with(
+                src_str, dest_str))
+        os_routines.data_definition.assert_called_once_with(
+            src_str, dest_str, (1 * 1024), use_direct_io=use_direct_io)
 
     @ddt.data((['1.1.1.1'], 4), (['1001::1001'], 6))
     @ddt.unpack
@@ -576,37 +653,38 @@ class LVMShareDriverTestCase(test.TestCase):
         self.assertEqual(version == 6, self._driver._stats['ipv6_support'])
 
     def test_revert_to_snapshot(self):
-        mock_update_access = self.mock_object(self._helper_nfs,
-                                              'update_access')
+        share_local_path = '/dev/mapper/fakevg-fakename'
+        snapshot_local_path = '/dev/mapper/fakevg-fakesnapshotname'
+        mock_update_access = self.mock_object(
+            self._helper_nfs, 'update_access')
+        mock__unmount_device = self.mock_object(
+            self._driver, '_unmount_device')
+        mock_lvconvert = self.mock_object(privsep_lvm, 'lvconvert')
+        mock_create_snapshot = self.mock_object(
+            self._driver, '_create_snapshot')
+        mock_mount_device = self.mock_object(
+            self._driver, '_mount_device')
+        mock_get_local_path = self.mock_object(
+            self._driver, '_get_local_path',
+            mock.Mock(side_effect=[share_local_path, snapshot_local_path]))
+        snapshot_parent_share = self.snapshot['share']
+
         self._driver.revert_to_snapshot(self._context, self.snapshot,
                                         [], [], self.share_server)
-        snap_lv = "%s/fakesnapshotname" % (CONF.lvm_share_volume_group)
-        share_lv = "%s/fakename" % (CONF.lvm_share_volume_group)
-        share_mount_path = self._get_mount_path(self.snapshot['share'])
-        snapshot_mount_path = self._get_mount_path(self.snapshot)
-        expected_exec = [
-            ('umount -f %s' % snapshot_mount_path),
-            ("rmdir %s" % snapshot_mount_path),
-            ("umount -f %s" % share_mount_path),
-            ("rmdir %s" % share_mount_path),
-            ("lvconvert --merge %s" % snap_lv),
-            ("lvcreate -L 1G --name fakesnapshotname --snapshot %s" %
-                share_lv),
-            ("e2fsck -y -f /dev/mapper/%s-fakesnapshotname" %
-                CONF.lvm_share_volume_group),
-            ("tune2fs -U random /dev/mapper/%s-fakesnapshotname" %
-                CONF.lvm_share_volume_group),
-            ("mkdir -p %s" % share_mount_path),
-            ("mount /dev/mapper/%s-fakename %s" %
-                (CONF.lvm_share_volume_group, share_mount_path)),
-            ("chmod 777 %s" % share_mount_path),
-            ("mkdir -p %s" % snapshot_mount_path),
-            ("mount /dev/mapper/fakevg-fakesnapshotname "
-             "%s" % snapshot_mount_path),
-            ("chmod 777 %s" % snapshot_mount_path),
-        ]
-        self.assertEqual(expected_exec, fake_utils.fake_execute_get_log())
         self.assertEqual(4, mock_update_access.call_count)
+        mock__unmount_device.assert_has_calls(
+            [mock.call(self.snapshot), mock.call(self.snapshot['share'])])
+        mock_lvconvert.assert_called_once_with(
+            CONF.lvm_share_volume_group, self.snapshot['name'])
+        mock_create_snapshot.assert_called_once_with(
+            self._context, self.snapshot)
+        mock_mount_device.assert_has_calls(
+            [mock.call(snapshot_parent_share, share_local_path),
+             mock.call(self.snapshot, snapshot_local_path)]
+        )
+        mock_get_local_path.assert_has_calls(
+            [mock.call(snapshot_parent_share),
+             mock.call(self.snapshot)])
 
     def test_snapshot_update_access(self):
         access_rules = [{
