@@ -26,8 +26,8 @@ class ContextTestCase(test.TestCase):
         admin_context = user_context.elevated()
         self.assertFalse(user_context.is_admin)
         self.assertTrue(admin_context.is_admin)
-        self.assertFalse('admin' in user_context.roles)
-        self.assertTrue('admin' in admin_context.roles)
+        self.assertNotIn('admin', user_context.roles)
+        self.assertIn('admin', admin_context.roles)
 
     def test_request_context_sets_is_admin(self):
         ctxt = context.RequestContext('111',
@@ -63,24 +63,3 @@ class ContextTestCase(test.TestCase):
                           ctxt,
                           'read_deleted',
                           True)
-
-    def test_extra_args_to_context_get_logged(self):
-        info = {}
-
-        def fake_warn(log_msg, other_args):
-            info['log_msg'] = log_msg % other_args
-
-        self.mock_object(context.LOG, 'warning', fake_warn)
-
-        c = context.RequestContext('user',
-                                   'project',
-                                   extra_arg1='meow',
-                                   extra_arg2='wuff',
-                                   user='user',
-                                   tenant='project')
-        self.assertTrue(c)
-        self.assertIn("'extra_arg1': 'meow'", info['log_msg'])
-        self.assertIn("'extra_arg2': 'wuff'", info['log_msg'])
-        # user and tenant kwargs get popped off before we log anything
-        self.assertNotIn("'user': 'user'", info['log_msg'])
-        self.assertNotIn("'tenant': 'project'", info['log_msg'])
