@@ -20,19 +20,20 @@ from unittest import mock
 import ddt
 import pycodestyle
 
-from manila.hacking import checks
 from manila import test
+from manila.tests.hacking import checks
 
 
 @ddt.ddt
 class HackingTestCase(test.TestCase):
     """Hacking test cases
 
-    This class tests the hacking checks in manila.hacking.checks by passing
-    strings to the check methods like the pep8/flake8 parser would. The parser
-    loops over each line in the file and then passes the parameters to the
-    check method. The parameter names in the check method dictate what type of
-    object is passed to the check method. The parameter types are::
+    This class tests the hacking checks in manila.tests.hacking.checks by
+    passing strings to the check methods like the pep8/flake8 parser would.
+    The parser loops over each line in the file and then passes the
+    parameters to the check method. The parameter names in the check method
+    dictate what type of object is passed to the check method. The
+    parameter types are::
 
         logical_line: A processed line with the following modifications:
             - Multi-line statements converted to a single line.
@@ -157,79 +158,6 @@ class HackingTestCase(test.TestCase):
         self._assert_has_errors(code.format(log_method), checker,
                                 expected_errors=[(4, mock.ANY, 'M310')])
 
-    def test_str_on_exception(self):
-
-        checker = checks.CheckForStrUnicodeExc
-        code = """
-               def f(a, b):
-                   try:
-                       p = str(a) + str(b)
-                   except ValueError as e:
-                       p = str(e)
-                   return p
-               """
-        errors = [(5, 16, 'M325')]
-        self._assert_has_errors(code, checker, expected_errors=errors)
-
-    def test_no_str_unicode_on_exception(self):
-        checker = checks.CheckForStrUnicodeExc
-        code = """
-               def f(a, b):
-                   try:
-                       p = unicode(a) + str(b)
-                   except ValueError as e:
-                       p = e
-                   return p
-               """
-        self._assert_has_no_errors(code, checker)
-
-    def test_unicode_on_exception(self):
-        checker = checks.CheckForStrUnicodeExc
-        code = """
-               def f(a, b):
-                   try:
-                       p = str(a) + str(b)
-                   except ValueError as e:
-                       p = unicode(e)
-                   return p
-               """
-        errors = [(5, 20, 'M325')]
-        self._assert_has_errors(code, checker, expected_errors=errors)
-
-    def test_str_on_multiple_exceptions(self):
-        checker = checks.CheckForStrUnicodeExc
-        code = """
-               def f(a, b):
-                   try:
-                       p = str(a) + str(b)
-                   except ValueError as e:
-                       try:
-                           p  = unicode(a) + unicode(b)
-                       except ValueError as ve:
-                           p = str(e) + str(ve)
-                       p = e
-                   return p
-               """
-        errors = [(8, 20, 'M325'), (8, 29, 'M325')]
-        self._assert_has_errors(code, checker, expected_errors=errors)
-
-    def test_str_unicode_on_multiple_exceptions(self):
-        checker = checks.CheckForStrUnicodeExc
-        code = """
-               def f(a, b):
-                   try:
-                       p = str(a) + str(b)
-                   except ValueError as e:
-                       try:
-                           p  = unicode(a) + unicode(b)
-                       except ValueError as ve:
-                           p = str(e) + unicode(ve)
-                       p = str(e)
-                   return p
-               """
-        errors = [(8, 20, 'M325'), (8, 33, 'M325'), (9, 16, 'M325')]
-        self._assert_has_errors(code, checker, expected_errors=errors)
-
     def test_trans_add(self):
 
         checker = checks.CheckForTransAdd
